package com.hncy.auth.inject.spring.boot.starter.common.extractor;

import com.hncy.auth.inject.spring.boot.starter.auth.AccTypeEnum;
import com.hncy.auth.inject.spring.boot.starter.auth.AuthUser;
import com.hncy.auth.inject.spring.boot.starter.common.factory.AuthUserFactory;
import com.hncy.auth.inject.spring.boot.starter.constant.Constant;
import com.hncy.jackson.spring.boot.starter.core.JSONObject;
import lombok.extern.slf4j.Slf4j;
import org.springframework.lang.NonNull;
import org.springframework.lang.Nullable;
import org.springframework.util.StringUtils;

import java.util.Optional;

/**
 * @Author: ying.dong
 * @Date: 2021/7/16 15:09
 */
@Slf4j
public class DefaultAuthInfoExtractor extends BaseAuthInfoExtractor<AuthUser> {

    private static final String USER_NAME = "user_name";
    private static final String ACCOUNT = "account";

    private final AuthUserFactory authUserFactory;

    public DefaultAuthInfoExtractor(@NonNull String authHeader, @NonNull AuthUserFactory authUserFactory) {
        super(authHeader);
        this.authUserFactory = authUserFactory;
    }

    @Override
    protected Optional<AuthUser> doExtract(String decodedAuthInfo) {
        Integer accType = getAccType(decodedAuthInfo);
        if (accType == null) {
            return Optional.empty();
        }
        AccTypeEnum accTypeEnum = AccTypeEnum.valueOf(accType).orElse(null);
        if (accTypeEnum == null) {
            return Optional.empty();
        }

        String loginAccount = getLoginAccount(decodedAuthInfo);
        if (StringUtils.isEmpty(loginAccount)) {
            return Optional.empty();
        }
        String account = getAccount(decodedAuthInfo);
        if (StringUtils.isEmpty(account)) {
            return Optional.empty();
        }

        return Optional.of(authUserFactory.getAuthUser(accTypeEnum, account, loginAccount));
    }

    @Override
    protected Optional<AuthUser> enhanceAuthInfo(@Nullable AuthUser authUser, String decodedAuthInfo) {
        return Optional.ofNullable(authUser);
    }

    /**
     * 获取账号类型
     * @param decodedAuthInfo
     * @return
     */
    private Integer getAccType(String decodedAuthInfo) {
        String userTypeStr = JSONObject.getInstance().findValueAsText(decodedAuthInfo, Constant.USER_TYPE);
        if (StringUtils.isEmpty(userTypeStr)) {
            return null;
        }
        return Integer.parseInt(userTypeStr);
    }

    /**
     * 获取登录账号
     * @param decodedAuthInfo
     * @return
     */
    private String getLoginAccount(String decodedAuthInfo) {
       return getStringFromJSON(decodedAuthInfo, USER_NAME);
    }

    /**
     * 获取系统账号
     * @param decodedAuthInfo
     * @return
     */
    private String getAccount(String decodedAuthInfo) {
        return getStringFromJSON(decodedAuthInfo, ACCOUNT);
    }


    /**
     *
     * @param decodedAuthInfo
     * @param field
     * @return
     */
    private String getStringFromJSON(String decodedAuthInfo, String field) {
        return JSONObject.getInstance().findValueAsText(decodedAuthInfo, field);
    }
}
