package com.hncy.auth.inject.spring.boot.starter.config;

import com.hncy.auth.inject.spring.boot.starter.auth.AuthUser;
import com.hncy.auth.inject.spring.boot.starter.common.extractor.AuthInfoExtractor;
import com.hncy.auth.inject.spring.boot.starter.common.extractor.DefaultAuthInfoExtractor;
import com.hncy.auth.inject.spring.boot.starter.common.factory.AuthUserFactory;
import com.hncy.auth.inject.spring.boot.starter.common.factory.DefaultAuthUserFactory;
import com.hncy.auth.inject.spring.boot.starter.holder.AuthUserHolder;
import com.hncy.auth.inject.spring.boot.starter.properties.AuthInjectProperties;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

/**
 * @Author: ying.dong
 * @Date: 2021/7/17 11:52
 */
@Configuration
@EnableConfigurationProperties(AuthInjectProperties.class)
public class AuthConfiguration {

    @ConditionalOnMissingBean
    @Bean
    AuthUserFactory authUserFactory() {
        return new DefaultAuthUserFactory();
    }

    @ConditionalOnMissingBean
    @Bean
    AuthInfoExtractor<AuthUser> authUserAuthInfoExtractor(AuthInjectProperties properties, AuthUserFactory authUserFactory) {
        return new DefaultAuthInfoExtractor(properties.getHeader(), authUserFactory);
    }

    @Bean
    AuthUserHolder authUserHolder(AuthInfoExtractor<AuthUser> extractor) {
        return new AuthUserHolder(extractor);
    }
}
