package com.hncy.auth.inject.spring.boot.starter.feign;

import com.hncy.auth.inject.spring.boot.starter.constant.Constant;
import com.hncy.auth.inject.spring.boot.starter.properties.AuthInjectProperties;
import com.hncy.auth.inject.spring.boot.starter.util.RequestUtil;
import feign.Feign;
import feign.RequestInterceptor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.boot.autoconfigure.AutoConfigureAfter;
import org.springframework.boot.autoconfigure.condition.ConditionalOnClass;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.cloud.openfeign.FeignAutoConfiguration;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.util.StringUtils;

/**
 * @Author: ying.dong
 * @Date: 2021/4/15 09:28
 */
@Slf4j
@Configuration
@ConditionalOnClass(Feign.class)
@AutoConfigureAfter(FeignAutoConfiguration.class)
public class FeignAuthUserInjectInterceptor {

    @ConditionalOnClass(Feign.class)
    @ConditionalOnMissingBean
    @Bean
    public RequestInterceptor authUserInjectInterceptor(AuthInjectProperties authInjectProperties) {
        return requestTemplate -> RequestUtil.getRequest()
                .ifPresent(it -> {
                    String authHeaderName = authInjectProperties.getHeader();
                    String authHeader = it.getHeader(authHeaderName);
                    String authType = it.getHeader(Constant.USER_TYPE);
                    if (!StringUtils.isEmpty(authHeader)) {
                        log.debug("auth user information injected. authHeader: [{}], authType: [{}]", authHeader, authType);
                        requestTemplate.header(authHeaderName, authHeader);
                        requestTemplate.header(Constant.USER_TYPE, authType);
                    }
                });
    }

}
