package com.hncy.auth.inject.spring.boot.starter.mvc;

import com.hncy.auth.inject.spring.boot.starter.auth.AuthUser;
import com.hncy.auth.inject.spring.boot.starter.common.extractor.AuthInfoExtractor;
import org.springframework.boot.autoconfigure.condition.ConditionalOnClass;
import org.springframework.core.MethodParameter;
import org.springframework.web.bind.support.WebDataBinderFactory;
import org.springframework.web.context.request.NativeWebRequest;
import org.springframework.web.method.support.HandlerMethodArgumentResolver;
import org.springframework.web.method.support.ModelAndViewContainer;
import org.springframework.web.servlet.DispatcherServlet;

import javax.servlet.http.HttpServletRequest;

/**
 *
 * 将Header中的认证信息注入到服务方法入参
 *
 * @Author: ying.dong
 * @Date: 2021/4/23 14:12
 */
@ConditionalOnClass(DispatcherServlet.class)
public class AuthUserInjectorResolver implements HandlerMethodArgumentResolver {

    private final AuthInfoExtractor<AuthUser> authUserAuthInfoExtractor;

    public AuthUserInjectorResolver(AuthInfoExtractor<AuthUser> authUserAuthInfoExtractor) {
        this.authUserAuthInfoExtractor = authUserAuthInfoExtractor;
    }

    @Override
    public boolean supportsParameter(MethodParameter parameter) {
        return AuthUser.class.isAssignableFrom(parameter.getParameterType());
    }

    @Override
    public Object resolveArgument(MethodParameter parameter, ModelAndViewContainer mavContainer, NativeWebRequest webRequest, WebDataBinderFactory binderFactory) throws Exception {
        HttpServletRequest request = webRequest.getNativeRequest(HttpServletRequest.class);
        return authUserAuthInfoExtractor.extract(request).orElse(null);
    }
}
