package com.hncy.doc.spring.boot.starter.config;

import com.hncy.doc.spring.boot.starter.aggregate.AggregateSwaggerResourceProvider;
import com.hncy.doc.spring.boot.starter.aggregate.ProxyWebMvcOpenApiTransformationFilter;
import com.netflix.zuul.filters.ZuulServletFilter;
import com.netflix.zuul.http.ZuulServlet;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.autoconfigure.condition.ConditionalOnClass;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.boot.autoconfigure.condition.ConditionalOnWebApplication;
import org.springframework.cloud.netflix.zuul.filters.ZuulProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Conditional;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Primary;
import springfox.documentation.oas.web.WebMvcOpenApiTransformationFilter;
import springfox.documentation.spring.web.OnServletBasedWebApplication;
import springfox.documentation.swagger.web.InMemorySwaggerResourcesProvider;
import springfox.documentation.swagger.web.SwaggerResourcesProvider;


/**
 * @Author: ying.dong
 * @Date: 2021/4/25 15:06
 */
@ConditionalOnProperty(
        value = {"springfox.documentation.enabled"},
        havingValue = "true",
        matchIfMissing = true
)
@Configuration
public class DocAggregateConfig {

    @Configuration
    @ConditionalOnClass({ZuulProperties.class,ZuulServlet.class, ZuulServletFilter.class})
    static class aggregateSwaggerResourcesProviderConfiguration {
        private final String DOC_V3 = "/v3/api-docs";

        @Value("${springfox.documentation.swagger.version:3.0.3}")
        private String swaggerVersion;

        @Primary
        @Bean
        SwaggerResourcesProvider aggregateSwaggerResourcesProvider(ZuulProperties zuulProperties,
                                                                   InMemorySwaggerResourcesProvider inMemorySwaggerResourcesProvider) {
            return new AggregateSwaggerResourceProvider(zuulProperties, inMemorySwaggerResourcesProvider, DOC_V3, swaggerVersion);
        }
    }

    @Configuration
    @ConditionalOnWebApplication(type = ConditionalOnWebApplication.Type.SERVLET)
    @Conditional(OnServletBasedWebApplication.class)
    static class CustomOpenApiWebConfiguration {

        @Primary
        @Bean
        public WebMvcOpenApiTransformationFilter proxyWebMvcOpenApiTransformer() {
            return new ProxyWebMvcOpenApiTransformationFilter();
        }
    }
}
