package com.hncy.exception.handler.spring.boot.starter.core.translator;

import com.hncy.common.exception.common.GlobalErrorConstants;
import com.hncy.exception.handler.spring.boot.starter.common.ApiResult;
import com.hncy.exception.handler.spring.boot.starter.common.ApiResultBuilder;
import com.hncy.exception.handler.spring.boot.starter.core.translator.base.ExceptionTranslator;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.HttpStatus;

/**
 * @Author: ying.dong
 * @Date: 2021/4/19 16:24
 */
@Slf4j
public class ExceptionTranslationExecutor implements ExceptionTranslator {

    @Override
    public ApiResult translate(Throwable throwable) {
        log.error("error: ", throwable);
        for (ExceptionTranslator translator: ExceptionTranslatorRegistry.getAll()) {
            if (!translator.support(throwable)) {
                continue;
            }
            ApiResult apiResult = translator.translate(throwable);
            if (apiResult != null) {
                return apiResult;
            }
        }
        log.warn("none exception translator matched. default result returned.");
        return ApiResultBuilder.build(GlobalErrorConstants.INTERNAL_SERVER_ERROR.getCode(), GlobalErrorConstants.INTERNAL_SERVER_ERROR.getMessage(), HttpStatus.INTERNAL_SERVER_ERROR);
    }

    @Override
    public boolean support(Throwable throwable) {
        return true;
    }
}
