package com.hncy.exception.handler.spring.boot.starter.core.translator;

import com.hncy.exception.handler.spring.boot.starter.core.translator.base.ExceptionTranslator;
import com.hncy.exception.handler.spring.boot.starter.core.translator.translators.CommonBusinessExceptionTranslator;
import com.hncy.exception.handler.spring.boot.starter.core.translator.translators.ConstraintViolationExceptionTranslator;
import com.hncy.exception.handler.spring.boot.starter.core.translator.translators.LocalBusinessExceptionTranslator;
import com.hncy.exception.handler.spring.boot.starter.core.translator.translators.UnsupportedExceptionTranslator;
import com.hncy.exception.handler.spring.boot.starter.core.translator.translators.webmvc.*;
import lombok.extern.slf4j.Slf4j;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;

/**
 * @Author: ying.dong
 * @Date: 2021/4/19 16:24
 */
@Slf4j
public final class ExceptionTranslatorRegistry {

    private static final Collection<ExceptionTranslator> EXCEPTION_TRANSLATORS = Collections.synchronizedSet(new LinkedHashSet<>());

    static  {
        /**
         * 系统调用链反向顺序(顺序有关优先级)
         */
        register(new UnsupportedExceptionTranslator());
        register(new CommonBusinessExceptionTranslator());
        register(new LocalBusinessExceptionTranslator());
        //web mvc
        register(new HttpMethodNotSupportedExceptionTranslator());
        register(new MethodArgumentNotValidExceptionTranslator());
        register(new WebBindingExceptionTranslator());
        register(new ValidationExceptionTranslator());
        register(new NoHandlerFoundExceptionTranslator());
        register(new RequestNotMappingExceptionTranslator());
        register(new ConstraintViolationExceptionTranslator());
        register(new ServletRequestBindingExceptionTranslator());
    }

    public static boolean register(ExceptionTranslator exceptionTranslator) {
        return EXCEPTION_TRANSLATORS.add(exceptionTranslator);
    }

    public static Collection<ExceptionTranslator> getAll() {
        List<ExceptionTranslator> temp = new ArrayList<>(EXCEPTION_TRANSLATORS);
        Collections.reverse(temp);
        log.debug("current registered exception translators: {}", temp);
        return Collections.unmodifiableCollection(temp);
    }
}
