package com.hncy.exception.handler.spring.boot.starter.core.translator.base;

import com.hncy.exception.handler.spring.boot.starter.common.ApiResult;
import com.hncy.exception.handler.spring.boot.starter.core.translator.ExceptionTranslatorRegistry;
import lombok.extern.slf4j.Slf4j;
import javax.annotation.PostConstruct;

/**
 * @Author: ying.dong
 * @Date: 2021/4/19 16:24
 */
@Slf4j
public abstract class AbstractExceptionTranslator implements ExceptionTranslator {

    @Override
    public ApiResult translate(Throwable throwable) {
        if (!support(throwable)) {
            log.info("{} not support for {}", this.getClass().getName(), throwable.toString());
            return null;
        }
        log.info("{} will be handled by {}.", throwable.toString(), this.getClass().getSimpleName());
        return doTranslate(throwable);
    }

    @PostConstruct
    private void registerSelf() {
        ExceptionTranslatorRegistry.register(this);
    }

    protected abstract ApiResult doTranslate(Throwable throwable);
}
