package com.hncy.exception.handler.spring.boot.starter.core.translator.translators.alarm;

import brave.Tracer;
import com.hncy.notifier.spring.boot.starter.core.Notifier;
import lombok.extern.slf4j.Slf4j;
import org.springframework.util.StringUtils;

/**
 * @Author: ying.dong
 * @Date: 2021/8/18 15:00
 */
@Slf4j
public class TracingAlarmTranslator extends DefaultAlarmTranslator {

    private final Tracer tracer;

    public TracingAlarmTranslator(Notifier notifier, Tracer tracer) {
        super(notifier);
        this.tracer = tracer;
    }

    @Override
    protected String doResolveContent() {
        String content = super.doResolveContent();
        String spanId = getTraceId();
        if (!StringUtils.isEmpty(spanId)) {
            content += "[" + spanId + "] ";
        }
        return content;
    }

    private String getTraceId() {
        try {
            return tracer.currentSpan().context().traceIdString();
        } catch (Exception e) {
            log.warn("cannot get spanId.", e);
        }
        return null;
    }
}
