package com.hncy.exception.handler.spring.boot.starter.handler;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.exceptions.ExceptionUtil;
import com.hncy.common.exception.common.GlobalErrorConstants;
import com.hncy.exception.handler.spring.boot.starter.common.ApiResult;
import com.hncy.exception.handler.spring.boot.starter.common.LocalResult;
import com.hncy.exception.handler.spring.boot.starter.core.translator.base.ExceptionTranslator;
import org.springframework.boot.autoconfigure.web.ErrorProperties;
import org.springframework.boot.autoconfigure.web.servlet.error.BasicErrorController;
import org.springframework.boot.web.servlet.error.ErrorAttributes;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.context.request.ServletWebRequest;

import javax.servlet.http.HttpServletRequest;
import java.util.Map;

/**
 * @Author: ying.dong
 * @Date: 2021/4/19 16:24
 */
@RequestMapping("${server.error.path:${error.path:/error}}")
public class GlobalExceptionController extends BasicErrorController {

    private final ExceptionTranslator exceptionTranslator;
    private final ErrorAttributes errorAttributes;

    public GlobalExceptionController(ExceptionTranslator exceptionTranslator, ErrorAttributes errorAttributes, ErrorProperties errorProperties) {
        super(errorAttributes, errorProperties);
        this.errorAttributes = errorAttributes;
        this.exceptionTranslator = exceptionTranslator;
    }

    @RequestMapping
    @ResponseBody
    public ResponseEntity<Map<String, Object>> error(HttpServletRequest request) {
        LocalResult localResult;
        HttpStatus httpStatus = getStatus(request);
        if (httpStatus.equals(HttpStatus.NOT_FOUND)) {
            localResult = new LocalResult();
            localResult.setCode(httpStatus.value());
            localResult.setMessage(GlobalErrorConstants.NOT_FOUND.getMessage());
        } else {
            ServletWebRequest servletWebRequest = new ServletWebRequest(request);
            Throwable error = errorAttributes.getError(servletWebRequest);
            if (error != null) {
                error = ExceptionUtil.getRootCause(error);
                ApiResult translate = exceptionTranslator.translate(error);
                localResult = translate.getBody();
                httpStatus = translate.getStatus();
            } else {
                localResult = new LocalResult();
                localResult.setCode(httpStatus.value());
                localResult.setMessage(GlobalErrorConstants.INTERNAL_SERVER_ERROR.getMessage());
            }
        }
        Map<String, Object> body = BeanUtil.beanToMap(localResult);
        return new ResponseEntity<>(body, httpStatus);
    }
}
