package com.hncy.feign.spring.boot.starter.decoder;

import com.hncy.feign.spring.boot.starter.exception.RPCException;
import com.hncy.jackson.spring.boot.starter.core.JSONObject;
import feign.FeignException;
import feign.Response;
import feign.RetryableException;
import feign.Util;
import feign.codec.ErrorDecoder;
import lombok.extern.slf4j.Slf4j;

import java.io.IOException;
import java.nio.charset.StandardCharsets;
import java.util.Map;

/**
 * @Author: ying.dong
 * @Date: 2021/6/11 14:24
 */
@Slf4j
public class DefaultErrorDecoder extends ErrorDecoder.Default {

    private static final String CODE = "code";
    private static final String MESSAGE = "message";

    @Override
    public Exception decode(String methodKey, Response response) {
        Exception exception = super.decode(methodKey, response);
        if (exception instanceof RetryableException) {
            return exception;
        }
        if (!(exception instanceof FeignException)) {
            return exception;
        }

        try {
            String result = Util.toString(response.body().asReader(StandardCharsets.UTF_8));
            Map<String, Object> jsonResult = JSONObject.getInstance().parseMap(result, String.class, Object.class);
            if (!jsonResult.containsKey(CODE) || !jsonResult.containsKey(MESSAGE)) {
                return exception;
            }
            FeignException feignException = (FeignException) exception;
            int code = Integer.parseInt(jsonResult.get(CODE).toString());
            return new RPCException(feignException.status(), code, jsonResult.get(MESSAGE).toString());
        } catch (IOException e) {
            log.error("error occurred while handling FeignException with: [{}]", methodKey);
        }
        return exception;
    }
}
