package com.hncy.file.manage.spring.boot.starter.oss.common;

import com.hncy.file.manage.spring.boot.starter.core.common.Registry;
import com.hncy.file.manage.spring.boot.starter.oss.properties.OSSProperties;
import com.hncy.file.manage.spring.boot.starter.oss.properties.OSSRoleProperties;
import lombok.extern.slf4j.Slf4j;

import java.util.Map;
import java.util.Optional;
import java.util.concurrent.ConcurrentHashMap;

/**
 * @Author: ying.dong
 * @Date: 2021/5/24 18:15
 */
@Slf4j
public class OSSClientRegistry implements Registry<String, OSSClient> {

    private final Map<String, OSSClient> registry = new ConcurrentHashMap<>();

    public OSSClientRegistry(OSSProperties ossProperties, OSSClientFactory factory) {
        for (Map<String, OSSRoleProperties> map: ossProperties.getOssRoleProperties()) {
            for (Map.Entry<String, OSSRoleProperties> entry: map.entrySet()) {
                OSSClient ossClient = factory.getObject(entry.getValue());
                boolean result = add(entry.getKey(), ossClient);
                log.info("ossClient [{}] registered with key [{}], result: {}", ossClient, entry.getKey(), result);
            }
        }
    }

    @Override
    public Optional<OSSClient> get(String s) {
        return Optional.ofNullable(registry.get(s));
    }

    @Override
    public boolean add(String s, OSSClient ossClient) {
        boolean result = registry.putIfAbsent(s, ossClient) == null;
        if (result) {
            log.warn("ossClient [{}] registered with key [{}] maybe duplicated, ignore...", ossClient, s);
        }
        return result;
    }

    @Override
    public boolean remove(String s) {
        return registry.remove(s) != null;
    }
}
