package com.hncy.file.manage.spring.boot.starter.oss.manager;

import com.aliyun.oss.HttpMethod;
import com.aliyun.oss.common.comm.ResponseMessage;
import com.aliyun.oss.model.ObjectMetadata;
import com.aliyun.oss.model.PutObjectResult;
import com.aliyun.oss.model.VoidResult;
import com.hncy.file.manage.spring.boot.starter.core.exception.ResourceException;
import com.hncy.file.manage.spring.boot.starter.core.exception.ResourceOperationException;
import com.hncy.file.manage.spring.boot.starter.oss.common.OSSClient;
import com.hncy.file.manage.spring.boot.starter.oss.common.OSSClientRegistry;
import com.hncy.file.manage.spring.boot.starter.oss.constant.OSSConstant;
import com.hncy.file.manage.spring.boot.starter.oss.properties.OSSRoleProperties;
import com.hncy.file.manage.spring.boot.starter.oss.resource.OSSResource;
import com.hncy.file.manage.spring.boot.starter.oss.resource.OSSServerResource;
import lombok.extern.slf4j.Slf4j;
import org.springframework.util.StringUtils;

import java.util.Optional;

/**
 * @Author: ying.dong
 * @Date: 2021/7/13 10:21
 */
@Slf4j
public class OSSServerManager extends OSSManager {

    public OSSServerManager(OSSClientRegistry ossClientRegistry) {
        super(ossClientRegistry);
    }

    @Override
    public OSSResource get(String role, OSSResource resource) throws ResourceException {
        throw new UnsupportedOperationException();
    }

    @Override
    public OSSResource save(String role, OSSResource resource, boolean allowOverride) throws ResourceException {
        if (!(resource instanceof OSSServerResource)) {
            throw new UnsupportedOperationException();
        }
        ObjectMetadata objectMetadata = new ObjectMetadata();
        if (!allowOverride) {
            objectMetadata.setHeader(OSSConstant.Headers.FORBID_OVERWRITE, "true");
        }

        OSSClient ossClient = getOSSClient(role);
        OSSRoleProperties configuration = ossClient.getConfiguration();
        String key = getFileName(configuration, resource);
        OSSServerResource ossServerResource = (OSSServerResource) resource;
        PutObjectResult putObjectResult = ossClient.getSDKClient().putObject(configuration.getBucket(), key, ossServerResource.getFile(), objectMetadata);
        if ((putObjectResult.getResponse() != null && !putObjectResult.getResponse().isSuccessful()) ||
                StringUtils.isEmpty(putObjectResult.getETag())) {
            String errorMsg = Optional.ofNullable(putObjectResult.getResponse())
                    .map(ResponseMessage::getErrorResponseAsString)
                    .orElse("upload file error.");
            throw new ResourceOperationException(errorMsg);
        }
        return resource;
    }

    @Override
    public boolean del(String role, OSSResource resource) throws ResourceException {
        OSSClient ossClient = getOSSClient(role);
        OSSRoleProperties roleProperties = ossClient.getConfiguration();

        permissionValidated(role, roleProperties, HttpMethod.DELETE);

        String bucket = roleProperties.getBucket();
        VoidResult result = ossClient.getSDKClient().deleteObject(bucket, getFileName(roleProperties, resource));
        if (!result.getResponse().isSuccessful()) {
            log.error("delete resource error, resource[{}], result: {}", resource, result);
            return false;
        }
        return true;
    }


}
