package com.hncy.file.manage.spring.boot.starter.oss.sdk;

import cn.hutool.core.util.URLUtil;
import com.aliyun.oss.ClientConfiguration;
import com.aliyun.oss.common.comm.DefaultServiceClient;
import com.aliyun.oss.common.comm.ExecutionContext;
import com.aliyun.oss.common.comm.ResponseMessage;
import lombok.extern.slf4j.Slf4j;

import java.io.IOException;
import java.net.URL;
import java.util.regex.Pattern;

/**
 * fix 自定义域名会被拼接为 endpoint/bucket/xxx 导致签名不通过的Bug
 * @Author: ying.dong
 * @Date: 2021/7/13 14:20
 */
@Slf4j
public class BugFixedServiceClient extends DefaultServiceClient {

    /**
     * URL合法性校验
     */
    private static final Pattern pattern = Pattern.compile("(https?|ftp|file)://[-A-Za-z0-9+&@#/%?=~_|!:,.;]+[-A-Za-z0-9+&@#/%=~_|]");

    private final String bucket;

    public BugFixedServiceClient(ClientConfiguration config, String bucket) {
        super(config);
        this.bucket = bucket;
    }

    @Override
    public ResponseMessage sendRequestCore(Request request, ExecutionContext context) throws IOException {
        if (!config.isSLDEnabled()) {
            return super.sendRequestCore(request, context);
        }
        String originalUrl = request.getUri();
        URL url = URLUtil.url(originalUrl);
        String path = url.getPath().replaceFirst("/" + bucket, "");
        String host = url.getHost();
        String finalUrl = URLUtil.normalize(host + path);
        log.info("oss url [{}] replace to [{}].", originalUrl, finalUrl);
        request.setUrl(finalUrl);
        return super.sendRequestCore(request, context);
    }
}
