package com.hncy.lock.spring.boot.starter.core;

import org.springframework.lang.NonNull;
import org.springframework.lang.Nullable;

import java.util.function.Supplier;

/**
 * @Author: ying.dong
 * @Date: 2021/5/27 15:00
 */
public interface Lock {

    /**
     * 加锁 (锁会自动释放，无需显式Unlock)
     * @param key
     * @param wait 获取锁等待时间(秒)
     * @param lease 锁定时间(秒)
     * @param handler 获取到锁时执行业务逻辑
     * @param timeoutHandler 在wait结束时仍然没有获取到锁时的执行逻辑
     */
    <T> T lock(@NonNull String key, long wait, long lease,
               @NonNull Supplier<T> handler, @Nullable Supplier<T> timeoutHandler);

    /**
     * 加锁 (锁会自动释放，无需显式Unlock)
     * @param key
     * @param wait 获取锁等待时间(秒)
     * @param lease 锁定时间(秒)
     * @param fastFail 快速失败（true: 遇到加锁，则立即执行超时逻辑）
     * @param handler 获取到锁时执行业务逻辑
     * @param timeoutHandler 在wait结束时仍然没有获取到锁时的执行逻辑
     */
    <T> T lock(@NonNull String key, long wait, long lease, boolean fastFail,
               @NonNull Supplier<T> handler, @Nullable Supplier<T> timeoutHandler);


    /**
     * 解除锁
     * @param key
     */
    void unlock(String key);
}
