package com.hncy.notifier.spring.boot.starter.core;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.lang.NonNull;
import org.springframework.util.StringUtils;

/**
 * @Author: ying.dong
 * @Date: 2021/8/6 13:39
 */
public abstract class AbstractNotifier implements Notifier {

    protected final Logger logger = LoggerFactory.getLogger(getClass());

    @Override
    public NotifierResult notify(Object object) {
        if (object == null) {
            logger.info("parameter must not be null. ignore...");
            return new DefaultNotifierResult(false);
        }
        String parameter = doResolveContent(object);
        if (StringUtils.isEmpty(parameter)) {
            logger.info("parameter must not be null. ignore...");
            return new DefaultNotifierResult(false);
        }
        return doNotify(parameter);
    }

    /**
     * 将需要通知的对象组装成String
     * @param object
     * @return
     */
    protected abstract String doResolveContent(Object object);

    /**
     * 通知
     * @param parameter
     * @return
     */
    protected abstract NotifierResult doNotify(@NonNull String parameter);
}
