package com.hncy.redis.spring.boot.starter.core;

import org.springframework.data.redis.connection.DataType;
import org.springframework.data.redis.core.HashOperations;
import org.springframework.data.redis.core.ListOperations;
import org.springframework.data.redis.core.RedisOperations;
import org.springframework.data.redis.core.SetOperations;

import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.concurrent.TimeUnit;
import java.util.function.Consumer;

/**
 * @Author: ying.dong
 * @Date: 2021/4/22 17:43
 */
public interface RedisRepository<V> {

    public void set(String key, V value);

    public V get(String key);

    public void setEx(String key, V value, long timeout);

    public Boolean setNx(String key, V value);

    public Boolean setNxEx(String key, V value, long timeout);

    public Long ttl(String key);

    public Long ttl(String key, TimeUnit timeUnit);

    public boolean del(String key);

    public void hset(String key, String hashKey, V value);

    public String hget(String key, String hashKey);

    public List<V> hMultiGet(String key, List<V> hashKeys);

    public Map<String, V> hgetAll(String key);

    public Long hdel(String key, String... hashKeys);

    public HashOperations<String, String, V> opsForHash();

    public ListOperations<String, V> opsForList();

    public SetOperations<String, V> opsForSet();

    public Set<V> keys(String pattern);

    //NONE("none"), STRING("string"), LIST("list"), SET("set"), ZSET("zset"), HASH("hash");
    public DataType type(String key);

    public List<V> lrange(final String key, final long start, final long stop);

    public long llen(String key);

    public Set<V> smembers(String key);

    public Boolean exists(String key);

    public void incr(String key);

    public long incrAndGet(String key);

    public void decr(String key);

    public void expire(String key, long timeout);

    public void expireAt(String key, Date date);

    public void rpush(String key, V value) ;

    public void setAdd(String key, V value);

    public V setPop(String key);

    public long setSize(String key);

    public V lindex(String key, long index);

    List<Object> executePipelined(RedisConnectionConsumer<String, V> consumer);

}
