package com.hncy.repeatable.check.spring.boot.starter.common;

import cn.hutool.core.util.ObjectUtil;
import com.hncy.common.constant.GlobalConstant;
import com.hncy.common.exception.custom.BaseBusinessException;
import com.hncy.common.exception.custom.BusinessException;
import com.hncy.lock.spring.boot.starter.core.Lock;
import com.hncy.repeatable.check.spring.boot.starter.interfaceann.RepeatableInterface;
import lombok.extern.slf4j.Slf4j;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Pointcut;
import org.aspectj.lang.reflect.MethodSignature;

import java.lang.reflect.Method;

@Aspect
@Slf4j
public class InterceptRequestAop {

    private final Lock lock;

    public InterceptRequestAop(Lock lock){
        this.lock = lock;
    }

    @Pointcut("@annotation(com.hncy.repeatable.check.spring.boot.starter.interfaceann.RepeatableInterface)")
    public void background(){}

    @Around("background()")
    public void beforeCut(ProceedingJoinPoint proceedingJoinPoint){
        MethodSignature methodSignature = (MethodSignature) proceedingJoinPoint.getSignature();
        Method method = methodSignature.getMethod();
        RepeatableInterface annotation = method.getAnnotation(RepeatableInterface.class);
        if (ObjectUtil.isNotNull(annotation)) {
            String uniqueKey = annotation.uniqueKey();
            lock.lock(GlobalConstant.RedisNameSpace.STARTER_REPEATABLE_CHECK+uniqueKey,1,2,()->{
                try {
                    proceedingJoinPoint.proceed();
                } catch (Throwable throwable) {
                    if (throwable instanceof BusinessException) {
                        throw (BusinessException)throwable;
                    }
                    throw new RuntimeException(throwable);
                }
                return null;
            },()->{
                throw new BusinessException("请勿重复点击");
            });
        }
    }
}
