package com.hncy.sms.spring.boot.starter.aliyun.request;

import cn.hutool.core.util.IdUtil;
import com.hncy.sms.spring.boot.starter.aliyun.util.UTCTimeUtil;
import lombok.Data;

/**
 * @Author: ying.dong
 * @Date: 2021/5/11 15:44
 */
@Data
public class AliyunSmsBaseRequest {

    private static final String DEFAULT_SIGN_METHOD = "HMAC-SHA1";
    private static final String DEFAULT_SIGNATURE_VERSION = "1.0";
    private static final String DEFAULT_API_VERSION = "2017-05-25";
    private static final String DEFAULT_ACTION = "SendSms";
    private static final String DEFAULT_FORMAT = "json";

    /**
     * 签名
     */
    private String Signature;

    /**
     * 访问密钥 ID。AccessKey 用于调用 API。
     * 必填
     */
    private String AccessKeyId;

    /**
     * API 的名称
     * 必填
     */
    private String Action = DEFAULT_ACTION;

    /**
     * 返回参数的语言类型。取值范围：json | xml。默认值：json
     * 非必填
     */
    private String Format = DEFAULT_FORMAT;

    /**
     * API支持的RegionID，如短信API的值为：cn-hangzhou
     * 非必填
     */
    private String RegionId;

    /**
     * 签名方式。取值范围：HMAC-SHA1
     * 必填
     */
    private String SignatureMethod = DEFAULT_SIGN_METHOD;

    /**
     * 签名唯一随机数。用于防止网络重放攻击，建议您每一次请求都使用不同的随机数。
     * 必填
     */
    private String SignatureNonce = IdUtil.randomUUID();

    /**
     * 签名算法版本。取值范围：1.0
     * 必填
     */
    private String SignatureVersion = DEFAULT_SIGNATURE_VERSION;

    /**
     * 请求的时间戳。按照ISO8601 标准表示，并需要使用UTC时间，格式为yyyy-MM-ddTHH:mm:ssZ。示例：2018-01-01T12:00:00Z 表示北京时间 2018 年 01 月 01 日 20 点 00 分 00 秒
     * 必填
     */
    private String Timestamp = UTCTimeUtil.now2String();

    /**
     * API 的版本号，格式为 YYYY-MM-DD。取值范围：2017-05-25
     * 必填
     */
    private String Version = DEFAULT_API_VERSION;
}
