package com.hncy.sms.spring.boot.starter.aliyun.util;

import cn.hutool.core.bean.BeanUtil;
import com.hncy.sms.spring.boot.starter.aliyun.request.AliyunSmsBaseRequest;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.HttpMethod;

import java.util.Map;
import java.util.TreeMap;

/**
 * @Author: ying.dong
 * @Date: 2021/5/11 16:42
 */
@Slf4j
public class AliyunSignatureBuilder {

    private static final String CHARSET = "UTF-8" ;
    private static final String HMAC = "HmacSHA1";

    private final String accessKey;
    private final String accessSecret;

    public AliyunSignatureBuilder(String accessKey, String accessSecret) {
        this.accessKey = accessKey;
        this.accessSecret = accessSecret;
    }

    /**
     * 构造参数（signature参数除外）
     * @param request
     * @return
     * @throws Exception
     */
    public String buildParams(AliyunSmsBaseRequest request) throws Exception {
        Map<String,Object> paramsMap = BeanUtil.beanToMap(request);
        TreeMap<String, Object> sortedMap = new TreeMap<>(paramsMap);
        log.info("sms params: {}", sortedMap);
        java.util.Iterator<String> it = sortedMap.keySet().iterator();
        StringBuilder sortQueryStringTmp = new StringBuilder();
        while (it.hasNext()) {
            String key = it.next();
            if (sortedMap.get(key) == null) {
                continue;
            }
            sortQueryStringTmp.append("&").append(specialUrlEncode(key)).append("=").append(specialUrlEncode(sortedMap.get(key).toString()));
        }
        return sortQueryStringTmp.substring(1);
    }

    /**
     * 构造签名
     * @param params
     * @return
     * @throws Exception
     */
    public String buildSignature(String params, HttpMethod method) throws Exception {
        StringBuilder stringToSign = new StringBuilder();
        stringToSign.append(method.name()).append("&");
        stringToSign.append(specialUrlEncode("/")).append("&");
        stringToSign.append(specialUrlEncode(params));
        String sign = sign(accessSecret + "&", stringToSign.toString());
        // 签名最后也要做特殊URL编码
        return specialUrlEncode(sign);
    }

    /**
     * 构造签名
     * @param request
     * @return
     * @throws Exception
     */
    public String buildSignature(AliyunSmsBaseRequest request, HttpMethod method) throws Exception {
        String params = buildParams(request);
        return buildSignature(params, method);
    }


    private String specialUrlEncode(String value) throws Exception {
        return java.net.URLEncoder.encode(value, CHARSET).replace("+", "%20").replace("*", "%2A").replace("%7E", "~");
    }

    private String sign(String accessSecret, String stringToSign) throws Exception {
        javax.crypto.Mac mac = javax.crypto.Mac.getInstance(HMAC);
        mac.init(new javax.crypto.spec.SecretKeySpec(accessSecret.getBytes(CHARSET), HMAC));
        byte[] signData = mac.doFinal(stringToSign.getBytes(CHARSET));
        return new sun.misc.BASE64Encoder().encode(signData);
    }

}
