package com.hncy.common.jwt.verifier;

import cn.hutool.core.exceptions.ValidateException;
import cn.hutool.jwt.JWT;
import cn.hutool.jwt.JWTValidator;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * @Author: ying.dong
 * @Date: 2021/10/13 09:40
 */
public abstract class BaseJWTVerifier implements JWTVerifier {

    protected Logger logger = LoggerFactory.getLogger(getClass());

    @Override
    public VerifierResult doVerify(String jwtToken) {
        VerifierResult verifierResult = new VerifierResult();
        try {
            JWT jwt = JWT.of(jwtToken);
            prepareJWT(jwt);
            boolean success = jwt.verify();
            verifierResult.setSuccess(success);
            expireValidate(jwt, verifierResult);
            doFieldValidate(jwt, verifierResult);
        } catch (Exception e) {
            logger.error("verify error.", e);
            verifierResult.setSuccess(false);
            verifierResult.setException(e);
        }
        return verifierResult;
    }

    /**
     * 判断是否过期
     * @param jwt
     * @param result
     */
    protected void expireValidate(JWT jwt, VerifierResult result) {
        try {
            JWTValidator.of(jwt).validateDate();
        } catch (ValidateException e) {
            result.setExpired(true);
            result.setSuccess(false);
        }
    }

    /**
     * JWT相关设置
     * @param jwt
     */
    protected abstract void prepareJWT(JWT jwt);

    /**
     * 相关属性校验
     * @param jwt
     * @param result
     */
    protected abstract void doFieldValidate(JWT jwt, VerifierResult result);
}
