package com.hncy.service.wechat.applet.biz.controller;

import com.hncy.service.wechat.applet.api.vo.WxUserInfo;
import com.hncy.service.wechat.applet.api.vo.WxUserVo;
import com.hncy.service.wechat.applet.biz.utils.WechatUtils;
import com.hncy.service.wechat.applet.biz.vo.JudegAccesstokenVo;
import com.hncy.service.wechat.applet.biz.vo.WechatAccesstokenVo;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;
import com.hncy.common.dto.ResultBean;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.hncy.service.wechat.applet.biz.entity.WxUser;
import com.hncy.service.wechat.applet.biz.service.WxUserService;
import org.springframework.beans.factory.annotation.Autowired;
import io.swagger.annotations.Api;

import java.time.LocalDateTime;

import org.springframework.web.bind.annotation.RestController;

/**
* <p>
    * 微信小程序用户表controller
    * </p>
*
* @author cs
* @since 2021-10-27
*/
@RestController
@RequestMapping("/wx-user")
@Slf4j
@Api(tags = "微信小程序用户表")
public class WxUserController {

    @Autowired
    private WxUserService wxUserService;

    @ApiOperation("解密敏感数据")
    @PostMapping(value = "/decryptSensitiveData",produces = "application/json;charset=UTF-8")
    public ResultBean decryptSensitiveData (@ApiParam(name = "encryptedData", value = "加密数据", required = true)@RequestParam(name = "encryptedData") String encryptedData,
                                            @ApiParam(name = "sessionKey", value = "会话秘钥", required = true)@RequestParam(name = "sessionKey") String sessionKey,
                                            @ApiParam(name = "iv", value = "加密向量", required = true)@RequestParam(name = "iv") String iv) {
        String result = WechatUtils.wxDecrypt(encryptedData, sessionKey, iv);
        return ResultBean.success(result);
    }

    @ApiOperation(value = "获取小程序用户信息，并保存")
    @PostMapping(value = "/saveWxUserInfo", produces = "application/json;charset=UTF-8")
    public ResultBean saveWxUserInfo (@ApiParam(name = "openId", value = "小程序id",required = true)@RequestParam("openId") String openId,
                                      @ApiParam(name = "avatar", value = "用户头像路径",required = true)@RequestParam("avatar") String avatar,
                                      @ApiParam(name = "nickname", value = "用户昵称",required = true)@RequestParam("nickname") String nickname,
                                      @ApiParam(name = "sexCode", value = "性别代码",required = true)@RequestParam("sexCode") String sexCode,
                                      @ApiParam(name = "sexName", value = "性别",required = true)@RequestParam("sexName") String sexName,
                                      @ApiParam(name = "tel", value = "电话",required = true)@RequestParam("tel") String tel) {
        return wxUserService.saveWxUserInfo(openId,avatar,nickname,sexCode,sexName,tel);
    }

    @ApiOperation(value = "根据openid获取小程序用户信息")
    @PostMapping(value = "/getWxUserInfo", produces = "application/json;charset=UTF-8")
    public ResultBean<WxUser> getWxUserInfo(@ApiParam(name = "openId", value = "openId", required = true)@RequestParam("openId") String openId) {
        WxUser wxUserInfo = wxUserService.getWxUserInfoByopenId(openId);
        return ResultBean.success(wxUserInfo);
    }

    @ApiOperation(value = "根据微信用户id查询openid(内部调用)")
    @PostMapping(value = "/getOpenId")
    ResultBean<WxUserInfo> getOpenId(@RequestParam("wxUserId") String wxUserId){
        return wxUserService.getOpenId(wxUserId);
    };

    @ApiOperation(value = "根据openid查询用户是否存在(内部调用)")
    @PostMapping(value = "/booleanWxUserByOpenId")
    ResultBean<WxUserVo> booleanWxUserByOpenId(@ApiParam(name = "openId", value = "openId", required = true)@RequestParam("openId") String openId){
        return wxUserService.booleanWxUserByOpenId(openId);
    };

    @ApiOperation(value = "保存微信用户(内部调用)")
    @PostMapping(value = "/saveWxUser")
    ResultBean<WxUserVo> saveWxUser(@ApiParam(name = "用户唯一标识", value = "openId", required = true)@RequestParam("openId") String openId,
                                    @ApiParam(name = "用户在开放平台的唯一标识符", value = "unionId", required = false)@RequestParam(value = "unionId", required = false) String unionId){
        return wxUserService.saveWxUser(openId,unionId);
    };

    @ApiOperation(value = "根据微信用户id获取用户名字(内部调用)")
    @PostMapping(value = "/getNickNameById")
    ResultBean<String> getNickNameById(@ApiParam(name = "id", value = "id", required = true)@RequestParam("id") String id){
        return wxUserService.getNickNameById(id);
    };

    @ApiOperation(value = "微信用户授权登录并且获取token")
    @PostMapping(value = "/appletLogin")
    ResultBean<WechatAccesstokenVo> appletLogin(@ApiParam(name = "code",value = "code",required = true)@RequestParam("code") String code){
        return wxUserService.appletLogin(code);
    };

    @ApiOperation(value = "判断token是否过期")
    @PostMapping(value = "/judgeTokenFrush")
    ResultBean<JudegAccesstokenVo> judgeTokenFrush() {
        return wxUserService.judgeTokenFrush();
    }

    @ApiOperation(value = "微信小程序登出并且清除token")
    @PostMapping(value = "/loginOut")
    ResultBean loginOut() {
        return wxUserService.loginOut();
    }



}
