package com.hncy.service.wechat.applet.biz.mini.common.context;

import com.hncy.common.constant.GlobalConstant;
import com.hncy.lock.spring.boot.starter.core.Lock;
import com.hncy.service.wechat.applet.biz.mini.common.store.AccessTokenStore;
import com.hncy.service.wechat.applet.biz.mini.config.MiniProgramProperties;
import com.hncy.service.wechat.applet.biz.mini.dto.input.AccessTokenInput;
import com.hncy.service.wechat.applet.biz.mini.dto.out.AccessTokenOutput;
import com.hncy.service.wechat.applet.biz.mini.feign.MiniProgramOriginalFeignClient;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;

/**
 * @Author: ying.dong
 * @Date: 2021/6/15 15:58
 */
@Slf4j
public class DefaultMiniProgramContext implements MiniProgramContext {

    private static final String LOCK_KEY = GlobalConstant.RedisNameSpace.SERVICE_APPLET + "LOCK_ACCESS_TOKEN";

    private final MiniProgramProperties programProperties;
    private final AccessTokenStore accessTokenStore;
    private final MiniProgramOriginalFeignClient miniProgramOriginalFeignClient;
    private final Lock lock;

    public DefaultMiniProgramContext(MiniProgramProperties programProperties, AccessTokenStore accessTokenStore,
                                     MiniProgramOriginalFeignClient miniProgramOriginalFeignClient, Lock lock) {
        this.programProperties = programProperties;
        this.accessTokenStore = accessTokenStore;
        this.miniProgramOriginalFeignClient = miniProgramOriginalFeignClient;
        this.lock = lock;
    }

    @Override
    public String getAppId() {
        return programProperties.getAppId();
    }

    @Override
    public String getSecret() {
        return programProperties.getSecret();
    }

    @Override
    public String getAccessToken() {
        String accessToken = accessTokenStore.getAccessToken();
        if (StringUtils.isNotBlank(accessToken)) {
            return accessToken;
        }
        return lock.lock(LOCK_KEY, 2, 4, () -> {
            String token = accessTokenStore.getAccessToken();
            if (StringUtils.isNotBlank(token)) {
                return token;
            }
            AccessTokenInput input = new AccessTokenInput(getAppId(), getSecret());
            AccessTokenOutput accessTokenOutput = miniProgramOriginalFeignClient.getAccessToken(input);
            if (!accessTokenOutput.isSuccess()) {
                log.warn("access token object: {}", accessTokenOutput);
                throw new RuntimeException("failed to get access_token");
            }
            token = accessTokenOutput.getAccessToken();
            log.info("store access_token: {}", token);
            accessTokenStore.store(token);
            return token;
        }, null);
    }
}
