package com.hncy.service.wechat.applet.biz.mini.service.impl;

import cn.hutool.core.util.URLUtil;
import com.hncy.service.wechat.applet.api.dto.output.BaseOutput;
import com.hncy.service.wechat.applet.api.dto.output.Code2SessionOutput;
import com.hncy.service.wechat.applet.biz.mini.common.context.MiniProgramContext;
import com.hncy.service.wechat.applet.biz.mini.dto.input.Code2SessionInput;
import com.hncy.service.wechat.applet.biz.mini.dto.input.SubscribeMessageInput;
import com.hncy.service.wechat.applet.biz.mini.feign.MiniProgramOriginalFeignClient;
import com.hncy.service.wechat.applet.biz.mini.service.MiniProgramService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeansException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationContextAware;
import org.springframework.lang.NonNull;
import org.springframework.lang.Nullable;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.nio.charset.StandardCharsets;
import java.util.Arrays;
import java.util.Map;
import java.util.Optional;

/**
 * @Author: ying.dong
 * @Date: 2021/6/21 17:26
 */
@Service
public class MiniProgramServiceImpl implements MiniProgramService, ApplicationContextAware {

    @Autowired
    private MiniProgramOriginalFeignClient miniProgramSNSFeignClient;

    @Autowired
    private MiniProgramContext context;

    @Autowired
    private ApplicationContext applicationContext;

    @Override
    public Code2SessionOutput login(String code) {
        Code2SessionInput input = new Code2SessionInput();
        input.setAppid(context.getAppId());
        input.setSecret(context.getSecret());
        input.setJs_code(code);
        return miniProgramSNSFeignClient.login(input);
    }

    @Override
    public String getAccessToken() {
        return context.getAccessToken();
    }

    @Override
    public BaseOutput sendSubscribeMessage(@NonNull String openId, @NonNull String templateId, @NonNull Map<String, Object> jsonData,
                                           @Nullable String page, @Nullable Map<String, Object> pageParams) {
        SubscribeMessageInput input = new SubscribeMessageInput();
        input.setMiniprogramState(getMiniProgramProfile().getProfile());
        input.setOpenId(openId);
        input.setTemplateId(templateId);
        input.setAccessToken(context.getAccessToken());
        if (StringUtils.isNotBlank(page)) {
            if (!CollectionUtils.isEmpty(pageParams)) {
                page = page + "?" + URLUtil.buildQuery(pageParams, StandardCharsets.UTF_8);
            }
            input.setPage(page);
        }
        input.setData(jsonData);
        return miniProgramSNSFeignClient.sendSubscribeMessage(input, context.getAccessToken());
    }

    /**
     * 获取当前激活的环境
     * @return
     */
    private MiniProgramProfile getMiniProgramProfile() {
        String[] activeProfiles = applicationContext.getEnvironment().getActiveProfiles();
        if (activeProfiles.length < 1) {
            return MiniProgramProfile.FORMAL;
        }
        ApplicationProfile applicationProfile = ApplicationProfile.valueOfProfile(activeProfiles[0]).orElse(null);
        if (applicationProfile == null) {
            return MiniProgramProfile.FORMAL;
        }
        switch (applicationProfile) {
            case DEVELOPER:
                return MiniProgramProfile.DEVELOPER;
            case TEST:
                return MiniProgramProfile.TRIAL;
            default:
                return MiniProgramProfile.FORMAL;
        }
    }

    @Override
    public void setApplicationContext(ApplicationContext applicationContext) throws BeansException {
        this.applicationContext = applicationContext;
    }


    /**
     * 程序profile
     */
    enum ApplicationProfile {
        DEVELOPER("dev"), TEST("test"), PRODUCTION("prod");

        private String profile;

        ApplicationProfile(String profile) {
            this.profile = profile;
        }

        public String getProfile() {
            return profile;
        }

        public static Optional<ApplicationProfile> valueOfProfile(String profile) {
            return Arrays.stream(values())
                    .filter(it -> it.getProfile().equalsIgnoreCase(profile))
                    .findFirst();
        }
    }

    /**
     * 小程序环境
     */
    enum MiniProgramProfile {
        DEVELOPER("developer"), TRIAL("trial"), FORMAL("formal");

        private String profile;

        MiniProgramProfile(String profile) {
            this.profile = profile;
        }

        public String getProfile() {
            return profile;
        }
    }
}
