package com.hncy.service.wechat.applet.biz.service;

import com.hncy.common.dto.ResultBean;
import com.hncy.service.wechat.applet.biz.dto.ComponentPictureDto;
import com.hncy.service.wechat.applet.biz.entity.ComponentDetail;
import com.baomidou.mybatisplus.extension.service.IService;
import com.hncy.service.wechat.applet.biz.vo.*;

import java.time.LocalDateTime;
import java.util.List;

/**
 * <p>
 * 部件详情 服务类
 * </p>
 *
 * @author cs
 * @since 2021-11-02
 */
public interface ComponentDetailService extends IService<ComponentDetail> {

    /**
     * @Description 获取城市系统的部件（内部调用）
     * @Date 2021/11/2 13:43
     * @param
     * @return
     */
    ResultBean getComponentByCtiySys();

    /**
     * @Description 获取城市部件类型以及立案条件
     * @Date 2021/11/2 13:44
     * @param
     * @return
     */
    ResultBean getComponentTypeAndRegCondByCtiySys();

    /**
     * @Description 判断AI扫描出的部件是否存在于后台数据库
     * @Date 2021/11/3 9:51
     * @param componentTypeName
     * @param xCode
     * @param yCode
     * @return List<AIScanComponentsVo>
     */
    ResultBean<ComponentAcquisitionVo> judgeAIComponentIsExist(String componentTypeName, String xCode, String yCode);

    /**
     * @Description 部件采集
     * @Date 2021/11/3 14:07
     * @param componentName
     * @param componentCode
     * @param componentSuperName
     * @param componentSuperCode
     * @param componentTypeName
     * @param componentTypeCode
     * @param componentAddress
     * @param xCode
     * @param yCode
     * @param patrolInspectionTime
     * @param regCondCode
     * @param regCondName
     * @param issueDescription
     * @param pictureIds
     * @param collectorNickName
     * @param collectorOpenId
     * @param issueNumber
     * @return
     */
    ResultBean componentAcquisition(String componentName,
                                    String componentCode,
                                    String componentSuperName,
                                    String componentSuperCode,
                                    String componentTypeName,
                                    String componentTypeCode,
                                    String componentAddress,
                                    String xCode,
                                    String yCode,
                                    LocalDateTime patrolInspectionTime,
                                    String regCondCode,
                                    String regCondName,
                                    String issueDescription,
                                    List<String> pictureIds,
                                    String collectorNickName,
                                    String collectorOpenId,
                                    String issueNumber);
    /**
     * @Description 获取今日巡检数，部件采集总数，上报采集总数
     * @Date 2021/11/3 15:27
     * @param collectorOpenId
     * @return
     */
    ResultBean<PatrolInspectionSumVo> selectTodaySum(String collectorOpenId);

    /**
     * @Description 获取今日巡检部件的类别和每个类别下的总数
     * @Date 2021/11/3 16:55
     * @param
     * @return
     */
    ResultBean<List<PatrolInspectionComponentsSumVo>> selectTodayComponentsTypeSum(String collectorOpenId);

    /**
     * @Description 添加巡检时间记录
     * @Date 2021/11/3 19:45
     * @param patrolInspectionTime
     * @param componentLogos
     * @return
     */
    ResultBean savepatrolInspectionTime(LocalDateTime patrolInspectionTime, List<String> componentLogos);

    /**
     * @Description 查询每个月的部件采集数量
     * @Date 2021/11/10 19:45
     * @param code
     * @return
     */
    ResultBean<List<CountMonthComponentsVo>> selectSumComponentsByMounth(String code,String type);

    /**
     * @Description 查询今日每个父类下面的部件数及类型
     * @Date 2021/11/11 14:28
     * @param code
     * @param type
     * @return
     */
    ResultBean<List<PatrolInspectionComponentsSuperTypeSumVo>> selectTodayComponentsSuperTypeSum(String code, String type);


    /**
     * @Description 当前区域下，获取ar巡检的总数，部件的完好数，异常数
     * @Date 2021/11/29 15:22
     * @param code
     * @param type
     * @return
     */
    ResultBean<CountComponentsVo> selectSumComponentsInDirection(String code, String type);

    /**
     * @Description
     * @Date 2021/11/30 19:44
     * @param code
     * @param type
     * @param componentCode
     * @param componentName
     * @return
     */
    ResultBean<List<ComponentsSearchVo>> selectDetailComponents(String code, String type, String componentCode, String componentName) ;

    /**
     * @Description 获取当前区域下今日巡检部件总数(拟态网格)
     * @Date 2021/12/7 17:02
     * @param code
     * @param type
     * @return
     */
    ResultBean<PatrolInspectionSumVoInDirection> selectTodaySumInDirection(String code, String type);


}
