package com.hncy.service.wechat.applet.biz.service.impl;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.date.DateTime;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.alibaba.nacos.common.utils.CollectionUtils;
import com.hncy.common.dto.ResultBean;
import com.hncy.common.exception.custom.BusinessException;
import com.hncy.common.exception.custom.LocalBusinessException;
import com.hncy.jackson.spring.boot.starter.core.JSONObject;
import com.hncy.service.wechat.applet.biz.dto.CountMounthComponentDto;
import com.hncy.service.wechat.applet.biz.entity.*;
import com.hncy.service.wechat.applet.biz.mapper.*;
import com.hncy.service.wechat.applet.biz.service.ComponentDetailService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.hncy.service.wechat.applet.biz.service.ComponentsRemoteService;
import com.hncy.service.wechat.applet.biz.utils.CoordTransform;
import com.hncy.service.wechat.applet.biz.utils.FastdfsClientUtil;
import com.hncy.service.wechat.applet.biz.vo.*;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.time.LocalDateTime;
import java.util.*;
import java.util.stream.Collectors;

/**
 * <p>
 * 部件详情 服务实现类
 * </p>
 *
 * @author cs
 * @since 2021-11-02
 */
@Service
@Slf4j
public class ComponentDetailServiceImpl extends ServiceImpl<ComponentDetailMapper, ComponentDetail> implements ComponentDetailService {

    private static final String GARABAGE = "垃圾箱";
    private static final String MANHOLE = "井盖";
    private static final String ZERO = "0";
    private static final String ONE = "1";
    private static final String TWO = "2";
    private static final String IN_GOOD_CONDITION = "完好";
/*    private final String COMMUNAL_FACILITIES = "公用设施";
    private final String CITY_APPEARANCE = "市容环境";
    private final String EXTENDS_PARTS = "拓展部件";*/

    private static final String GRID = "grid";
    private static final String COMMUNITY = "community";
    private static final String STREET = "street";
    private static final String DISTRICT = "district";

    //文件储存ip地址
    @Value("${file.upload}")
    private String basePath;

    @Autowired
    private ComponentsRemoteService componentsRemoteService;
    @Autowired
    private ComponentDetailMapper componentDetailMapper;
    @Autowired
    private ComponentIssuesReportMapper componentIssuesReportMapper;
    @Autowired
    private ComponentIssueReportRelationMapper componentIssueReportRelationMapper;
    @Autowired
    private FastdfsClientUtil fastdfsClientUtil;
    @Autowired
    private ComponentPictureMapper componentPictureMapper;
    @Autowired
    private ComponentPictureRelationMapper componentPictureRelationMapper;
    @Autowired
    private PlatformAuditMapper platformAuditMapper;
    @Autowired
    private CityGridMapper cityGridMapper;
    @Autowired
    private CommunityGridMapper communityGridMapper;
    @Autowired
    private StreetGridMapper streetGridMapper;
    @Autowired
    private DyGridMapper dyGridMapper;

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ResultBean getComponentByCtiySys() {
        List<Map<String, Object>> maps = componentsRemoteService.loadAllComponents();
        for (Map<String, Object> map : maps) {
            String componentLogo = map.get("code").toString();
            String componentName = map.get("name").toString();
            String xCode = map.get("lon").toString();
            String yCode = map.get("lat").toString();
            if(componentName.equalsIgnoreCase("垃圾箱")) {
                ComponentDetail componentDetail = new ComponentDetail();
                componentDetail.setComponentLogo(componentLogo);
                componentDetail.setComponentName(componentName);
                componentDetail.setXCode(xCode);
                componentDetail.setYCode(yCode);
                componentDetail.setComponentTypeName(GARABAGE);
                componentDetail.setComponentTypeCode(ONE);
                componentDetailMapper.insert(componentDetail);
            }else {
                //井盖
                ComponentDetail componentDetail = new ComponentDetail();
                componentDetail.setComponentLogo(componentLogo);
                componentDetail.setComponentName(componentName);
                componentDetail.setXCode(xCode);
                componentDetail.setYCode(yCode);
                componentDetail.setComponentTypeName(MANHOLE);
                componentDetail.setComponentTypeCode(TWO);
                componentDetailMapper.insert(componentDetail);
            }
        }
        return ResultBean.success();
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ResultBean getComponentTypeAndRegCondByCtiySys() {
        Map<String, Object> stringObjectMap = componentsRemoteService.queryTypeAndRegCond();
        String s = JSONObject.getInstance().toJSONString(stringObjectMap);
        log.info(s);

/*        //部门大小类
        List<Map<String,String>> typeLists = (List<Map<String, String>>) stringObjectMap.get("typeList");
        for(Map<String,String> typeList : typeLists) {
            String subClassName = typeList.get("subClassName");
            String subClassCode = typeList.get("subClassCode");
            String bigClassName = typeList.get("bigClassName");
            String bigClassCode = typeList.get("bigClassCode");

            List<ComponentDetail> componentDetails = componentDetailMapper.selectBySubClassName(subClassName);
            componentDetails.stream().forEach(componentDetail -> {
                componentDetail.setComponentCode(subClassCode);
                componentDetail.setComponentSuperCode(bigClassCode);
                componentDetail.setComponentSuperName(bigClassName);
                componentDetailMapper.updateById(componentDetail);
            });
        }
        //上报问题案件类型
        List<Map<String,String>> regCondLists = (List<Map<String, String>>) stringObjectMap.get("regCondList");
        for (Map<String,String> regCondList : regCondLists) {
            String regCondCode = regCondList.get("regCondCode");
            String regCondName = regCondList.get("regCondName");
            ComponentIssuesReport componentIssuesReport = new ComponentIssuesReport();
            componentIssuesReport.setRegCondCode(regCondCode);
            componentIssuesReport.setRegCondName(regCondName);
            componentIssuesReportMapper.insert(componentIssuesReport);
            String comIssuesId = componentIssuesReport.getId();

            String subClassCode = regCondList.get("subClassCode");
            String subClassName = regCondList.get("subClassName");
            ComponentDetail componentDetail = componentDetailMapper.selectBySubClassNameAndsubClassCode(subClassCode,subClassName);
            ComponentIssueReportRelation componentIssueReportRelation = new ComponentIssueReportRelation();
            componentIssueReportRelation.setComponentObjId(componentDetail.getId());
            componentIssueReportRelation.setComponentIssuesId(comIssuesId);
            componentIssueReportRelationMapper.insert(componentIssueReportRelation);
        }*/

        return ResultBean.success(s);
    }

    @Override
    public ResultBean<ComponentAcquisitionVo> judgeAIComponentIsExist(String componentTypeName, String xCode, String yCode) {
        log.info("当前时间: {} ,扫描人的位置经度: {} 以及纬度: {} ,以及当前扫描坐标距离部件坐标的距离distance: {}",DateTime.now(),xCode,yCode);

        ComponentAcquisitionVo componentAcquisitionVo = new ComponentAcquisitionVo();
        List<AIScanComponentsVo> aiScanComponentsVos = new ArrayList<>();
        List<ComponentSubsVo> componentSubsVos = new ArrayList<>();

        List<ComponentDetailVo> componentDetails = componentDetailMapper.judgeAIComponentIsExist(componentTypeName,xCode,yCode);
        if(CollectionUtil.isEmpty(componentDetails)) {
            throw new LocalBusinessException(430,componentTypeName);
        }

        componentDetails
                .stream()
                .forEach(componentDetail -> {
            log.info("当前时间: {} ,查询出的部件经度: {} 以及纬度: {} ,以及当前扫描人坐标距离部件坐标的距离distance: {}",DateTime.now(),xCode,yCode,componentDetail.getDistance());
            componentAcquisitionVo.setComponentTypeCode(componentDetail.getComponentTypeCode());
            componentAcquisitionVo.setComponentTypeName(componentDetail.getComponentTypeName());
            if(ObjectUtil.isNotEmpty(componentDetail.getComponentLogo())) {
                ComponentSubsVo componentSubsVo = new ComponentSubsVo();
                BeanUtils.copyProperties(componentDetail,componentSubsVo);
                List<ComponentIssuesReport> componentIssuesReports = componentIssuesReportMapper.selectIssueIdByComponentId(componentDetail.getId());
                componentIssuesReports.stream().forEach(componentIssuesReport -> {
                    componentSubsVo.setRegCondName(componentIssuesReport.getRegCondName());
                    componentSubsVo.setRegCondCode(componentIssuesReport.getRegCondCode());
                    componentSubsVos.add(componentSubsVo);
                });
            }
        });
        Map<String, List<ComponentSubsVo>> collect = componentSubsVos
                                                    .stream()
                                                    .collect(Collectors.groupingBy(ComponentSubsVo :: getComponentName));
        for(String componentName : collect.keySet()) {
            AIScanComponentsVo aiScanComponentsVo = new AIScanComponentsVo();
            for (ComponentSubsVo componentSubsVo : collect.get(componentName)) {
                aiScanComponentsVo.setComponentName(componentSubsVo.getComponentName());
                aiScanComponentsVo.setComponentCode(componentSubsVo.getComponentCode());
                aiScanComponentsVo.setComponentSubsVoList(collect.get(componentName));
                aiScanComponentsVo.setSum(String.valueOf(collect.get(componentName).size()));
            }
            aiScanComponentsVos.add(aiScanComponentsVo);
        }
        componentAcquisitionVo.setAiScanComponentsVoList(aiScanComponentsVos);
        return ResultBean.success(componentAcquisitionVo);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ResultBean componentAcquisition(String componentName,
                                           String componentCode,
                                           String componentSuperName,
                                           String componentSuperCode,
                                           String componentTypeName,
                                           String componentTypeCode,
                                           String componentAddress,
                                           String xCode,
                                           String yCode,
                                           LocalDateTime patrolInspectionTime,
                                           String regCondCode,
                                           String regCondName,
                                           String issueDescription,
                                           List<String> pictureIds,
                                           String collectorNickName,
                                           String collectorOpenId,
                                           String issueNumber) {
        log.info("传入的部件图片ids"+pictureIds.toString());
        log.info("当前时间: {} 部件采集传入的经度: {} 以及纬度: {} ",DateTime.now(),xCode,yCode);

        //部件详情
        ComponentDetail componentDetail = new ComponentDetail();
        componentDetail.setComponentName(componentName);
        componentDetail.setComponentCode(componentCode);
        componentDetail.setComponentSuperName(componentSuperName);
        componentDetail.setComponentSuperCode(componentSuperCode);
        componentDetail.setComponentTypeName(componentTypeName);
        componentDetail.setComponentTypeCode(componentTypeCode);
        componentDetail.setComponentAddress(componentAddress);
        componentDetail.setXCode(xCode);
        componentDetail.setYCode(yCode);
        componentDetail.setPatrolInspectionTime(patrolInspectionTime);
        componentDetail.setDeleted(0);
        componentDetail.setGmtCreate(DateTime.now());
        componentDetail.setCreateBy(collectorOpenId);
        int insert = componentDetailMapper.insert(componentDetail);
        if(insert == 0) {
            throw new BusinessException("部件采集失败，请重新采集");
        }
        String componentId = componentDetail.getId();

        //部件采集与图片关联
        pictureIds.stream().forEach(pictureId ->{
            ComponentPictureRelation componentPictureRelation = new ComponentPictureRelation();
            componentPictureRelation.setComponentDetailId(componentId);
            componentPictureRelation.setComponentPictureId(pictureId);
            componentPictureRelation.setComponentIssuesReportId(null);
            componentPictureRelation.setDeleted(0);
            componentPictureRelation.setGmtCreate(DateTime.now());
            componentPictureRelation.setCreateBy(collectorOpenId);
            int insert2 = componentPictureRelationMapper.insert(componentPictureRelation);
            if(insert2 == 0) {
                throw new BusinessException("部件采集失败，请重新采集");
            }
        });

        //部件问题上报
        ComponentIssuesReport componentIssuesReport = new ComponentIssuesReport();
        componentIssuesReport.setComponentReportName(componentName);
        componentIssuesReport.setComponentReportCode(componentCode);
        componentIssuesReport.setRegCondName(regCondName);
        componentIssuesReport.setRegCondCode(regCondCode);
        componentIssuesReport.setIssueDescription(issueDescription);
        componentIssuesReport.setDeleted(0);
        componentIssuesReport.setGmtCreate(DateTime.now());
        componentIssuesReport.setCreateBy(collectorOpenId);
        int insert1 = componentIssuesReportMapper.insert(componentIssuesReport);
        if(insert1 == 0) {
            throw new BusinessException("部件采集失败，请重新采集");
        }
        String issueId = componentIssuesReport.getId();

        //新增关联关系
        ComponentIssueReportRelation componentIssueReportRelation = new ComponentIssueReportRelation();
        componentIssueReportRelation.setComponentIssuesId(issueId);
        componentIssueReportRelation.setComponentObjId(componentId);
        componentIssueReportRelation.setDeleted(0);
        componentIssueReportRelation.setGmtCreate(DateTime.now());
        componentIssueReportRelation.setCreateBy(collectorOpenId);
        int insert2 = componentIssueReportRelationMapper.insert(componentIssueReportRelation);
        if(insert2 == 0) {
            throw new BusinessException("部件采集失败，请重新采集");
        }

        //上报给平台端审核
        PlatformAudit platformAudit = new PlatformAudit();
        platformAudit.setComponentName(componentName);
        platformAudit.setComponentDetailId(componentId);
        platformAudit.setComponentStatus(regCondName);
        platformAudit.setComponentCollector(collectorNickName);
        platformAudit.setComponentCollectTime(DateTime.now());
        platformAudit.setAuditStatus("1");
        platformAudit.setAuditTime(null);
        platformAudit.setComponentIssuesReportId(issueId);
        platformAudit.setDeleted(0);
        platformAudit.setGmtCreate(DateTime.now());
        int insert3 = platformAuditMapper.insert(platformAudit);
        if(insert3 == 0) {
            throw new BusinessException("部件采集失败，请重新采集");
        }

        //如果部件案件条件不是完好则上报给城市管理系统
        if(!IN_GOOD_CONDITION.equalsIgnoreCase(regCondName)) {
            Map<String, Object> map = new HashMap<>();
            //获取图片
            Map<String, String> fileMap = new HashMap<>();
            if(CollectionUtil.isNotEmpty(pictureIds)) {
                pictureIds.stream().forEach(pictureId -> {
                    ComponentPicture componentPicture = componentPictureMapper.selectComponentPicture(pictureId);
                    if(ObjectUtil.isNotEmpty(componentPicture)) {
                        String pictureUrl = componentPicture.getComponentPictureUrl();
                        String imageToBase64 = FastdfsClientUtil.image2Base64(pictureUrl);
                        fileMap.put(componentPicture.getComponentPictureName(),imageToBase64);
                    }else {
                        fileMap.put("fileMap",null);
                    }
                });
            }else {
                fileMap.put("fileMap",null);
            }
            //获取案件主键：32位UUID
            String caseInfoId = UUID.randomUUID().toString().replaceAll("-", "");
            map.put("fileMap",fileMap);
            map.put("caseInfoId",caseInfoId);
            map.put("addr",componentAddress);
            map.put("problemDesc",issueDescription);
            map.put("bigClassCode",componentSuperCode);
            map.put("bigClassName",componentSuperName);
            map.put("subClassCode",componentCode);
            map.put("subClassName",componentName);
            map.put("regCondCode",regCondCode);
            map.put("regCondName",regCondName);
            map.put("lon",xCode);
            map.put("lat",yCode);
            try {
                componentsRemoteService.reportByAR(map);
            }catch (Exception e){
                log.error(e.getMessage());
                throw new LocalBusinessException(432,"城管系统异常，请稍后再试");
            }
        }
        return ResultBean.success("部件信息上报成功");
    }

    @Override
    public ResultBean<PatrolInspectionSumVo> selectTodaySum(String collectorOpenId) {
        PatrolInspectionSumVo patrolInspectionSumVo = new PatrolInspectionSumVo();
        String patrolInspection = componentDetailMapper.selectTodaySum(collectorOpenId);
        String componentAcquisition = componentDetailMapper.selectTodayComponentsSum(collectorOpenId);
        String reportIssue = componentIssuesReportMapper.selectTodaySum(collectorOpenId);
        List<ComponentIssuesReport> componentIssuesReports = componentIssuesReportMapper.selectTodayIssue(collectorOpenId);
        if(CollectionUtils.isNotEmpty(componentIssuesReports)) {
            List<ComponentIssuesReport> componentIssuesReportList = componentIssuesReports
                    .stream()
                    .filter(item -> (IN_GOOD_CONDITION.equalsIgnoreCase(item.getRegCondName())))
                    .collect(Collectors.toList());
            patrolInspectionSumVo.setComponentWellSum(String.valueOf(componentIssuesReportList.size()));
            List<ComponentIssuesReport> map = componentIssuesReports
                    .stream()
                    .filter(item ->(!IN_GOOD_CONDITION.equalsIgnoreCase(item.getRegCondName())))
                    .collect(Collectors.toList());
            patrolInspectionSumVo.setComponentAbnormalSum(String.valueOf(map.size()));
        }else {
            patrolInspectionSumVo.setComponentWellSum("0");
            patrolInspectionSumVo.setComponentAbnormalSum("0");
        }
        patrolInspectionSumVo.setPatrolInspectionSum(patrolInspection);
        patrolInspectionSumVo.setComponentAcquisitionSum(componentAcquisition);
        patrolInspectionSumVo.setReportIssueSum(reportIssue);
        return ResultBean.success(patrolInspectionSumVo);
    }

    @Override
    public ResultBean<List<PatrolInspectionComponentsSumVo>> selectTodayComponentsTypeSum(String collectorOpenId) {
        List<PatrolInspectionComponentsSumVo> patrolInspectionComponentsSumVos = new ArrayList<>();
        List<ComponentDetail> componentDetails = componentDetailMapper.selectTodayComponentsTypeSum(collectorOpenId);
        Map<String,List<ComponentDetail>> map = componentDetails.stream().collect(Collectors.groupingBy(ComponentDetail::getComponentName));
        for(String component : map.keySet()) {
            PatrolInspectionComponentsSumVo patrolInspectionComponentsSumVo = new PatrolInspectionComponentsSumVo();
            patrolInspectionComponentsSumVo.setPatrolInspectionComponentsTypeName(component);
            patrolInspectionComponentsSumVo.setPatrolInspectionComponentsSum(String.valueOf(map.get(component).size()));
            patrolInspectionComponentsSumVos.add(patrolInspectionComponentsSumVo);
        }
        return ResultBean.success(patrolInspectionComponentsSumVos);
    }

    @Override
    public ResultBean savepatrolInspectionTime(LocalDateTime patrolInspectionTime, List<String> componentLogos) {
        componentLogos.stream().forEach(componentLogo ->{
            int insert = componentDetailMapper.savepatrolInspectionTime(patrolInspectionTime,componentLogo);
            if(insert == 0) {
                throw new BusinessException("添加巡检记录失败");
            }
        });
        return ResultBean.success("添加巡检记录成功");
    }

    @Override
    public ResultBean<List<CountMonthComponentsVo>> selectSumComponentsByMounth(String code,String type) {
        List<CountMonthComponentsVo> countMonthComponentsVos = new ArrayList<>();
        switch (type) {
            case DISTRICT:
                List<CountMounthComponentDto> countMounthComponentDtos = cityGridMapper.selectSumComponentsByMounth(code);
                log.info(countMounthComponentDtos.toString());
                if(CollectionUtil.isNotEmpty(countMounthComponentDtos)) {
                    Map<String,List<CountMounthComponentDto>> map = countMounthComponentDtos
                            .stream()
                            .filter(item -> (item != null && item.toString() != ""))
                            .collect(Collectors.groupingBy(CountMounthComponentDto::getGmtMouth,LinkedHashMap::new,Collectors.toList()));
                    log.info(map.toString());
                    for (String month : map.keySet()) {
                        CountMonthComponentsVo countMonthComponentsVo = new CountMonthComponentsVo();
                        List<CountMounthComponentDto> countMounthComponentDtos1 = map.get(month);
                        countMonthComponentsVo.setGmtMouth(month + "月");
                        countMonthComponentsVo.setComponentSum(String.valueOf(countMounthComponentDtos1.size()));
                        countMonthComponentsVos.add(countMonthComponentsVo);
                    }
                }else {
                    CountMonthComponentsVo countMonthComponentsVo = new CountMonthComponentsVo();
                    countMonthComponentsVo.setGmtMouth(null);
                    countMonthComponentsVo.setComponentSum(null);
                    countMonthComponentsVos.add(countMonthComponentsVo);
                }
                break;
            case GRID:
                List<CountMounthComponentDto> countMounthComponentDtoDyGrid = dyGridMapper.selectSumComponentsByMounth(code);
                log.info(countMounthComponentDtoDyGrid.toString());
                if(CollectionUtil.isNotEmpty(countMounthComponentDtoDyGrid)) {
                    Map<String,List<CountMounthComponentDto>> map = countMounthComponentDtoDyGrid
                            .stream()
                            .filter(item -> (item != null && item.toString() != ""))
                            .collect(Collectors.groupingBy(CountMounthComponentDto::getGmtMouth,LinkedHashMap::new,Collectors.toList()));
                    log.info(map.toString());
                    for (String month : map.keySet()) {
                        CountMonthComponentsVo countMonthComponentsVo = new CountMonthComponentsVo();
                        List<CountMounthComponentDto> countMounthComponentDtos1 = map.get(month);
                        countMonthComponentsVo.setGmtMouth(month + "月");
                        countMonthComponentsVo.setComponentSum(String.valueOf(countMounthComponentDtos1.size()));
                        countMonthComponentsVos.add(countMonthComponentsVo);
                    }
                }else {
                    CountMonthComponentsVo countMonthComponentsVo = new CountMonthComponentsVo();
                    countMonthComponentsVo.setGmtMouth(null);
                    countMonthComponentsVo.setComponentSum(null);
                    countMonthComponentsVos.add(countMonthComponentsVo);
                }
                break;
            case STREET:
                List<CountMounthComponentDto> countMounthComponentDtoStreet = streetGridMapper.selectSumComponentsByMounth(code);
                log.info(countMounthComponentDtoStreet.toString());
                if(CollectionUtil.isNotEmpty(countMounthComponentDtoStreet)) {
                    Map<String,List<CountMounthComponentDto>> map = countMounthComponentDtoStreet
                            .stream()
                            .filter(item -> (item != null && item.toString() != ""))
                            .collect(Collectors.groupingBy(CountMounthComponentDto::getGmtMouth,LinkedHashMap::new,Collectors.toList()));
                    log.info(map.toString());
                    for (String month : map.keySet()) {
                        CountMonthComponentsVo countMonthComponentsVo = new CountMonthComponentsVo();
                        List<CountMounthComponentDto> countMounthComponentDtos1 = map.get(month);
                        countMonthComponentsVo.setGmtMouth(month + "月");
                        countMonthComponentsVo.setComponentSum(String.valueOf(countMounthComponentDtos1.size()));
                        countMonthComponentsVos.add(countMonthComponentsVo);
                    }
                }else {
                    CountMonthComponentsVo countMonthComponentsVo = new CountMonthComponentsVo();
                    countMonthComponentsVo.setGmtMouth(null);
                    countMonthComponentsVo.setComponentSum(null);
                    countMonthComponentsVos.add(countMonthComponentsVo);
                }
                break;
            case COMMUNITY:
                List<CountMounthComponentDto> countMounthComponentDtoCommunity = communityGridMapper.selectSumComponentsByMounth(code);
                log.info(countMounthComponentDtoCommunity.toString());
                if(CollectionUtil.isNotEmpty(countMounthComponentDtoCommunity)) {
                    Map<String,List<CountMounthComponentDto>> map = countMounthComponentDtoCommunity
                            .stream()
                            .filter(item -> (item != null && item.toString() != ""))
                            .collect(Collectors.groupingBy(CountMounthComponentDto::getGmtMouth,LinkedHashMap::new,Collectors.toList()));
                    log.info(map.toString());
                    for (String month : map.keySet()) {
                        CountMonthComponentsVo countMonthComponentsVo = new CountMonthComponentsVo();
                        List<CountMounthComponentDto> countMounthComponentDtos1 = map.get(month);
                        countMonthComponentsVo.setGmtMouth(month + "月");
                        countMonthComponentsVo.setComponentSum(String.valueOf(countMounthComponentDtos1.size()));
                        countMonthComponentsVos.add(countMonthComponentsVo);
                    }
                }else {
                    CountMonthComponentsVo countMonthComponentsVo = new CountMonthComponentsVo();
                    countMonthComponentsVo.setGmtMouth(null);
                    countMonthComponentsVo.setComponentSum(null);
                    countMonthComponentsVos.add(countMonthComponentsVo);
                }
                break;
        }
        return ResultBean.success(countMonthComponentsVos);
    }

    @Override
    public ResultBean<List<PatrolInspectionComponentsSuperTypeSumVo>> selectTodayComponentsSuperTypeSum(String code, String type) {
        List<PatrolInspectionComponentsSuperTypeSumVo> patrolInspectionComponentsSuperTypeSumVos = new ArrayList<>();
        switch (type) {
            case DISTRICT:
                List<ComponentDetail> componentDetails = cityGridMapper.selectTodayComponentsTypeSum(code);
                Map<String,List<ComponentDetail>> map = componentDetails.stream().collect(Collectors.groupingBy(ComponentDetail::getComponentSuperName));
                for(String componentSuperName : map.keySet()) {
                    PatrolInspectionComponentsSuperTypeSumVo patrolInspectionComponentsSuperTypeSumVo = new PatrolInspectionComponentsSuperTypeSumVo();
                    patrolInspectionComponentsSuperTypeSumVo.setPatrolInspectionComponentsSuperTypeName(componentSuperName);
                    List<PatrolInspectionComponentsSumVo> patrolInspectionComponentsSumVos = new ArrayList<>();
                    List<ComponentDetail> componentDetails1 = map.get(componentSuperName);
                    Map<String,List<ComponentDetail>> map1 = componentDetails1.stream().collect(Collectors.groupingBy(ComponentDetail::getComponentName));
                    for(String component : map1.keySet()) {
                        PatrolInspectionComponentsSumVo patrolInspectionComponentsSumVo = new PatrolInspectionComponentsSumVo();
                        patrolInspectionComponentsSumVo.setPatrolInspectionComponentsTypeName(component);
                        patrolInspectionComponentsSumVo.setPatrolInspectionComponentsSum(String.valueOf(map1.get(component).size()));
                        patrolInspectionComponentsSumVos.add(patrolInspectionComponentsSumVo);
                    }
                    patrolInspectionComponentsSuperTypeSumVo.setPatrolInspectionComponentsSumVos(patrolInspectionComponentsSumVos);
                    patrolInspectionComponentsSuperTypeSumVos.add(patrolInspectionComponentsSuperTypeSumVo);
                }
                break;
            case COMMUNITY:
                List<ComponentDetail> componentDetailCommunity = communityGridMapper.selectTodayComponentsTypeSum(code);
                Map<String,List<ComponentDetail>> mapCommunity = componentDetailCommunity.stream().collect(Collectors.groupingBy(ComponentDetail::getComponentSuperName));
                for(String componentSuperName : mapCommunity.keySet()) {
                    PatrolInspectionComponentsSuperTypeSumVo patrolInspectionComponentsSuperTypeSumVo = new PatrolInspectionComponentsSuperTypeSumVo();
                    patrolInspectionComponentsSuperTypeSumVo.setPatrolInspectionComponentsSuperTypeName(componentSuperName);
                    List<PatrolInspectionComponentsSumVo> patrolInspectionComponentsSumVos = new ArrayList<>();
                    List<ComponentDetail> componentDetails1 = mapCommunity.get(componentSuperName);
                    Map<String,List<ComponentDetail>> map1 = componentDetails1.stream().collect(Collectors.groupingBy(ComponentDetail::getComponentName));
                    for(String component : map1.keySet()) {
                        PatrolInspectionComponentsSumVo patrolInspectionComponentsSumVo = new PatrolInspectionComponentsSumVo();
                        patrolInspectionComponentsSumVo.setPatrolInspectionComponentsTypeName(component);
                        patrolInspectionComponentsSumVo.setPatrolInspectionComponentsSum(String.valueOf(map1.get(component).size()));
                        patrolInspectionComponentsSumVos.add(patrolInspectionComponentsSumVo);
                    }
                    patrolInspectionComponentsSuperTypeSumVo.setPatrolInspectionComponentsSumVos(patrolInspectionComponentsSumVos);
                    patrolInspectionComponentsSuperTypeSumVos.add(patrolInspectionComponentsSuperTypeSumVo);
                }
                break;
            case STREET:
                List<ComponentDetail> componentDetailStreet = streetGridMapper.selectTodayComponentsTypeSum(code);
                Map<String,List<ComponentDetail>> mapStreet = componentDetailStreet.stream().collect(Collectors.groupingBy(ComponentDetail::getComponentSuperName));
                for(String componentSuperName : mapStreet.keySet()) {
                    PatrolInspectionComponentsSuperTypeSumVo patrolInspectionComponentsSuperTypeSumVo = new PatrolInspectionComponentsSuperTypeSumVo();
                    patrolInspectionComponentsSuperTypeSumVo.setPatrolInspectionComponentsSuperTypeName(componentSuperName);
                    List<PatrolInspectionComponentsSumVo> patrolInspectionComponentsSumVos = new ArrayList<>();
                    List<ComponentDetail> componentDetails1 = mapStreet.get(componentSuperName);
                    Map<String,List<ComponentDetail>> map1 = componentDetails1.stream().collect(Collectors.groupingBy(ComponentDetail::getComponentName));
                    for(String component : map1.keySet()) {
                        PatrolInspectionComponentsSumVo patrolInspectionComponentsSumVo = new PatrolInspectionComponentsSumVo();
                        patrolInspectionComponentsSumVo.setPatrolInspectionComponentsTypeName(component);
                        patrolInspectionComponentsSumVo.setPatrolInspectionComponentsSum(String.valueOf(map1.get(component).size()));
                        patrolInspectionComponentsSumVos.add(patrolInspectionComponentsSumVo);
                    }
                    patrolInspectionComponentsSuperTypeSumVo.setPatrolInspectionComponentsSumVos(patrolInspectionComponentsSumVos);
                    patrolInspectionComponentsSuperTypeSumVos.add(patrolInspectionComponentsSuperTypeSumVo);
                }
                break;
            case GRID:
                List<ComponentDetail> componentDetailsDyGrid = dyGridMapper.selectTodayComponentsTypeSum(code);
                Map<String,List<ComponentDetail>> mapDyGrid = componentDetailsDyGrid.stream().collect(Collectors.groupingBy(ComponentDetail::getComponentSuperName));
                for(String componentSuperName : mapDyGrid.keySet()) {
                    PatrolInspectionComponentsSuperTypeSumVo patrolInspectionComponentsSuperTypeSumVo = new PatrolInspectionComponentsSuperTypeSumVo();
                    patrolInspectionComponentsSuperTypeSumVo.setPatrolInspectionComponentsSuperTypeName(componentSuperName);
                    List<PatrolInspectionComponentsSumVo> patrolInspectionComponentsSumVos = new ArrayList<>();
                    List<ComponentDetail> componentDetails1 = mapDyGrid.get(componentSuperName);
                    Map<String,List<ComponentDetail>> map1 = componentDetails1.stream().collect(Collectors.groupingBy(ComponentDetail::getComponentName));
                    for(String component : map1.keySet()) {
                        PatrolInspectionComponentsSumVo patrolInspectionComponentsSumVo = new PatrolInspectionComponentsSumVo();
                        patrolInspectionComponentsSumVo.setPatrolInspectionComponentsTypeName(component);
                        patrolInspectionComponentsSumVo.setPatrolInspectionComponentsSum(String.valueOf(map1.get(component).size()));
                        patrolInspectionComponentsSumVos.add(patrolInspectionComponentsSumVo);
                    }
                    patrolInspectionComponentsSuperTypeSumVo.setPatrolInspectionComponentsSumVos(patrolInspectionComponentsSumVos);
                    patrolInspectionComponentsSuperTypeSumVos.add(patrolInspectionComponentsSuperTypeSumVo);
                }
                break;
        }
        return ResultBean.success(patrolInspectionComponentsSuperTypeSumVos);
    }

    @Override
    public ResultBean<CountComponentsVo> selectSumComponentsInDirection(String code, String type) {
        CountComponentsVo countComponentsVo = new CountComponentsVo();
        switch (type) {
            case DISTRICT:
                //这个接口响应17秒，需重构
                //当前区域下支持ar巡检的部件总数
                String componentDetailSumDistrict = cityGridMapper.selectSumComponentsInDirection(code);
                countComponentsVo.setComponentSum(componentDetailSumDistrict);
                //当前区域下ar巡检部件的完好和异常数目
                String componentWellSumDistrict = cityGridMapper.selectComponentWellSum(code);
                countComponentsVo.setComponentWell(componentWellSumDistrict);
                String componentAbnormalSumDistrict = cityGridMapper.selectComponentAbnormalSum(code);
                countComponentsVo.setComponentAbnormal(componentAbnormalSumDistrict);

                /*List<ComponentDetail> componentDetails = cityGridMapper.selectSumComponentsInDirection(code);
                if(CollectionUtil.isNotEmpty(componentDetails)) {
                    countComponentsVo.setComponentSum(String.valueOf(componentDetails.size()));
                }else {
                    countComponentsVo.setComponentSum("0");
                }
                componentDetails.stream().forEach(componentDetail -> {
                    List<ComponentIssueReportRelation> componentIssueReportRelationList = componentIssueReportRelationMapper.selectIssueIdByComponentId(componentDetail.getId());
                    if(CollectionUtil.isNotEmpty(componentIssueReportRelationList)) {
                        componentIssueReportRelationList.stream().forEach(componentIssueReportRelation -> {
                            ComponentIssuesReport componentIssuesReport = componentIssuesReportMapper.selectById(componentIssueReportRelation.getComponentIssuesId());
                            int well = 0;
                            int abnormal = 0;
                            if(IN_GOOD_CONDITION.equalsIgnoreCase(componentIssuesReport.getRegCondName())) {
                                well++;
                                countComponentsVo.setComponentWell(String.valueOf(well));
                            }else {
                                abnormal++;
                                countComponentsVo.setComponentAbnormal(String.valueOf(abnormal));
                            }
                        });
                    }else {
                        countComponentsVo.setComponentWell("0");
                        countComponentsVo.setComponentAbnormal("0");
                    }
                });*/
            break;
            case COMMUNITY:
                //这个接口响应17秒，需重构
                //当前区域下支持ar巡检的部件总数
                String componentDetailSumCommunity = communityGridMapper.selectSumComponentsInDirection(code);
                countComponentsVo.setComponentSum(componentDetailSumCommunity);
                //当前区域下ar巡检部件的完好和异常数目
                String componentWellSumCommunity = communityGridMapper.selectComponentWellSum(code);
                countComponentsVo.setComponentWell(componentWellSumCommunity);
                String componentAbnormalSumCommunity = communityGridMapper.selectComponentAbnormalSum(code);
                countComponentsVo.setComponentAbnormal(componentAbnormalSumCommunity);

                /*List<ComponentDetail> componentDetailCommunity = communityGridMapper.selectSumComponentsInDirection(code);
                if(CollectionUtil.isNotEmpty(componentDetailCommunity)) {
                    countComponentsVo.setComponentSum(String.valueOf(componentDetailCommunity.size()));
                }else {
                    countComponentsVo.setComponentSum("0");
                }
                componentDetailCommunity.stream().forEach(componentDetail -> {
                    List<ComponentIssueReportRelation> componentIssueReportRelationList = componentIssueReportRelationMapper.selectIssueIdByComponentId(componentDetail.getId());
                    if(CollectionUtil.isNotEmpty(componentIssueReportRelationList)) {
                        componentIssueReportRelationList.stream().forEach(componentIssueReportRelation -> {
                            ComponentIssuesReport componentIssuesReport = componentIssuesReportMapper.selectById(componentIssueReportRelation.getComponentIssuesId());
                            int well = 0;
                            int abnormal = 0;
                            if(IN_GOOD_CONDITION.equalsIgnoreCase(componentIssuesReport.getRegCondName())) {
                                well++;
                                countComponentsVo.setComponentWell(String.valueOf(well));
                            }else {
                                abnormal++;
                                countComponentsVo.setComponentAbnormal(String.valueOf(abnormal));
                            }
                        });
                    }else {
                        countComponentsVo.setComponentWell("0");
                        countComponentsVo.setComponentAbnormal("0");
                    }
                });*/
            break;
            case STREET:
                //这个接口响应17秒，需重构
                //当前区域下支持ar巡检的部件总数
                String componentDetailSumStreet = streetGridMapper.selectSumComponentsInDirection(code);
                countComponentsVo.setComponentSum(componentDetailSumStreet);
                //当前区域下ar巡检部件的完好和异常数目
                String componentWellSumStreet = streetGridMapper.selectComponentWellSum(code);
                countComponentsVo.setComponentWell(componentWellSumStreet);
                String componentAbnormalSumStreet = streetGridMapper.selectComponentAbnormalSum(code);
                countComponentsVo.setComponentAbnormal(componentAbnormalSumStreet);

                /*List<ComponentDetail> componentDetailStreet = streetGridMapper.selectSumComponentsInDirection(code);
                if(CollectionUtil.isNotEmpty(componentDetailStreet)) {
                    countComponentsVo.setComponentSum(String.valueOf(componentDetailStreet.size()));
                }else {
                    countComponentsVo.setComponentSum("0");
                }
                componentDetailStreet.stream().forEach(componentDetail -> {
                    List<ComponentIssueReportRelation> componentIssueReportRelationList = componentIssueReportRelationMapper.selectIssueIdByComponentId(componentDetail.getId());
                    if(CollectionUtil.isNotEmpty(componentIssueReportRelationList)) {
                        componentIssueReportRelationList.stream().forEach(componentIssueReportRelation -> {
                            ComponentIssuesReport componentIssuesReport = componentIssuesReportMapper.selectById(componentIssueReportRelation.getComponentIssuesId());
                            int well = 0;
                            int abnormal = 0;
                            if(IN_GOOD_CONDITION.equalsIgnoreCase(componentIssuesReport.getRegCondName())) {
                                well++;
                                countComponentsVo.setComponentWell(String.valueOf(well));
                            }else {
                                abnormal++;
                                countComponentsVo.setComponentAbnormal(String.valueOf(abnormal));
                            }
                        });
                    }else {
                        countComponentsVo.setComponentWell("0");
                        countComponentsVo.setComponentAbnormal("0");
                    }
                });*/
            break;
            case GRID:
                //这个接口响应17秒，需重构
                //当前区域下支持ar巡检的部件总数
                String componentDetailSumDyGrid = dyGridMapper.selectSumComponentsInDirection(code);
                countComponentsVo.setComponentSum(componentDetailSumDyGrid);
                //当前区域下ar巡检部件的完好和异常数目
                String componentWellSumDyGrid = dyGridMapper.selectComponentWellSum(code);
                countComponentsVo.setComponentWell(componentWellSumDyGrid);
                String componentAbnormalSumDyGrid = dyGridMapper.selectComponentAbnormalSum(code);
                countComponentsVo.setComponentAbnormal(componentAbnormalSumDyGrid);

                /*List<ComponentDetail> componentDetailDyGrid = dyGridMapper.selectSumComponentsInDirection(code);
                if(CollectionUtil.isNotEmpty(componentDetailDyGrid)) {
                    countComponentsVo.setComponentSum(String.valueOf(componentDetailDyGrid.size()));
                }else {
                    countComponentsVo.setComponentSum("0");
                }
                componentDetailDyGrid.stream().forEach(componentDetail -> {
                    List<ComponentIssueReportRelation> componentIssueReportRelationList = componentIssueReportRelationMapper.selectIssueIdByComponentId(componentDetail.getId());
                    if(CollectionUtil.isNotEmpty(componentIssueReportRelationList)) {
                        componentIssueReportRelationList.stream().forEach(componentIssueReportRelation -> {
                            ComponentIssuesReport componentIssuesReport = componentIssuesReportMapper.selectById(componentIssueReportRelation.getComponentIssuesId());
                            int well = 0;
                            int abnormal = 0;
                            if(IN_GOOD_CONDITION.equalsIgnoreCase(componentIssuesReport.getRegCondName())) {
                                well++;
                                countComponentsVo.setComponentWell(String.valueOf(well));
                            }else {
                                abnormal++;
                                countComponentsVo.setComponentAbnormal(String.valueOf(abnormal));
                            }
                        });
                    }else {
                        countComponentsVo.setComponentWell("0");
                        countComponentsVo.setComponentAbnormal("0");
                    }
                });*/
            break;
        }
        return ResultBean.success(countComponentsVo);
    }

    @Override
    public ResultBean<List<ComponentsSearchVo>> selectDetailComponents(String code, String type, String componentCode, String componentName) {
        List<ComponentsSearchVo> componentsSearchVos = new ArrayList<>();
        switch (type) {
            case DISTRICT:
                List<ComponentDetail> componentDetailListDistrict = cityGridMapper.selectDetailComponents(code,componentCode,componentName);
                if(CollectionUtil.isNotEmpty(componentDetailListDistrict)) {
                    componentDetailListDistrict.stream().forEach(componentDetail -> {
                        ComponentsSearchVo componentsSearchVo = new ComponentsSearchVo();
                        componentsSearchVo.setComponentAddress(componentDetail.getComponentAddress());
                        componentsSearchVo.setComponentLogo(componentDetail.getComponentLogo());
                        componentsSearchVo.setComponentCode(componentDetail.getComponentCode());
                        componentsSearchVo.setComponentName(componentDetail.getComponentName());
                        componentsSearchVo.setComponentSuperCode(componentDetail.getComponentSuperCode());
                        componentsSearchVo.setComponentSuperName(componentDetail.getComponentSuperName());
                        try {
                            if(null != componentDetail.getPatrolInspectionTime() && "" != componentDetail.getPatrolInspectionTime().toString()) {
                                LocalDateTime patrolInspectionTime = componentDetail.getPatrolInspectionTime();
                                SimpleDateFormat format =  new SimpleDateFormat("yyyy-MM-dd");
                                String format1 = format.format(format.parse(patrolInspectionTime.toString()));
                                log.info("巡检时间      "+format1);
                                String format2 = format.format(format.parse(DateTime.now().toString()));
                                log.info("当前时间      "+format2);
                                if(format1.equalsIgnoreCase(format2)) {
                                    componentsSearchVo.setIsPatrolInspection(ONE);
                                }else {
                                    componentsSearchVo.setIsPatrolInspection(ZERO);
                                }
                            }else {
                                componentsSearchVo.setIsPatrolInspection(ZERO);
                            }
                        } catch (ParseException e) {
                            log.error("时间转换失败"+e.getMessage());
                        }
                        String baiduLng = componentDetail.getXCode();
                        String baiduLat = componentDetail.getYCode();
                        double[] doubles = CoordTransform.transformBD09ToWGS84(Double.valueOf(baiduLng), Double.valueOf(baiduLat));
                        for(int i = 0; i < doubles.length; i++) {
                            String WGS84Lng = String.valueOf(doubles[0]);
                            componentsSearchVo.setXCode(WGS84Lng);
                            String WGS84Lat = String.valueOf(doubles[1]);
                            componentsSearchVo.setYCode(WGS84Lat);
                        }
                        componentsSearchVos.add(componentsSearchVo);
                    });
                }
            break;
            case STREET:
                List<ComponentDetail> componentDetailListStreet = streetGridMapper.selectDetailComponents(code,componentCode,componentName);
                if(CollectionUtil.isNotEmpty(componentDetailListStreet)) {
                    componentDetailListStreet.stream().forEach(componentDetail -> {
                        ComponentsSearchVo componentsSearchVo = new ComponentsSearchVo();
                        componentsSearchVo.setComponentAddress(componentDetail.getComponentAddress());
                        componentsSearchVo.setComponentLogo(componentDetail.getComponentLogo());
                        componentsSearchVo.setComponentCode(componentDetail.getComponentCode());
                        componentsSearchVo.setComponentName(componentDetail.getComponentName());
                        componentsSearchVo.setComponentSuperCode(componentDetail.getComponentSuperCode());
                        componentsSearchVo.setComponentSuperName(componentDetail.getComponentSuperName());
                        try {
                            if(null != componentDetail.getPatrolInspectionTime() && "" != componentDetail.getPatrolInspectionTime().toString()) {
                                LocalDateTime patrolInspectionTime = componentDetail.getPatrolInspectionTime();
                                SimpleDateFormat format =  new SimpleDateFormat("yyyy-MM-dd");
                                String format1 = format.format(format.parse(patrolInspectionTime.toString()));
                                log.info("巡检时间      "+format1);
                                String format2 = format.format(format.parse(DateTime.now().toString()));
                                log.info("当前时间      "+format2);
                                if(format1.equalsIgnoreCase(format2)) {
                                    componentsSearchVo.setIsPatrolInspection(ONE);
                                }else {
                                    componentsSearchVo.setIsPatrolInspection(ZERO);
                                }
                            }else {
                                componentsSearchVo.setIsPatrolInspection(ZERO);
                            }
                        } catch (ParseException e) {
                            log.error("时间转换失败"+e.getMessage());
                        }
                        String baiduLng = componentDetail.getXCode();
                        String baiduLat = componentDetail.getYCode();
                        double[] doubles = CoordTransform.transformBD09ToWGS84(Double.valueOf(baiduLng), Double.valueOf(baiduLat));
                        for(int i = 0; i < doubles.length; i++) {
                            String WGS84Lng = String.valueOf(doubles[0]);
                            componentsSearchVo.setXCode(WGS84Lng);
                            String WGS84Lat = String.valueOf(doubles[1]);
                            componentsSearchVo.setYCode(WGS84Lat);
                        }
                        componentsSearchVos.add(componentsSearchVo);
                    });
                }
            break;
            case COMMUNITY:
                List<ComponentDetail> componentDetailListCommunity = communityGridMapper.selectDetailComponents(code,componentCode,componentName);
                if(CollectionUtil.isNotEmpty(componentDetailListCommunity)) {
                    componentDetailListCommunity.stream().forEach(componentDetail -> {
                        ComponentsSearchVo componentsSearchVo = new ComponentsSearchVo();
                        componentsSearchVo.setComponentAddress(componentDetail.getComponentAddress());
                        componentsSearchVo.setComponentLogo(componentDetail.getComponentLogo());
                        componentsSearchVo.setComponentCode(componentDetail.getComponentCode());
                        componentsSearchVo.setComponentName(componentDetail.getComponentName());
                        componentsSearchVo.setComponentSuperCode(componentDetail.getComponentSuperCode());
                        componentsSearchVo.setComponentSuperName(componentDetail.getComponentSuperName());
                        try {
                            if(null != componentDetail.getPatrolInspectionTime() && "" != componentDetail.getPatrolInspectionTime().toString()) {
                                LocalDateTime patrolInspectionTime = componentDetail.getPatrolInspectionTime();
                                SimpleDateFormat format =  new SimpleDateFormat("yyyy-MM-dd");
                                String format1 = format.format(format.parse(patrolInspectionTime.toString()));
                                log.info("巡检时间      "+format1);
                                String format2 = format.format(format.parse(DateTime.now().toString()));
                                log.info("当前时间      "+format2);
                                if(format1.equalsIgnoreCase(format2)) {
                                    componentsSearchVo.setIsPatrolInspection(ONE);
                                }else {
                                    componentsSearchVo.setIsPatrolInspection(ZERO);
                                }
                            }else {
                                componentsSearchVo.setIsPatrolInspection(ZERO);
                            }
                        } catch (ParseException e) {
                            log.error("时间转换失败"+e.getMessage());
                        }
                        String baiduLng = componentDetail.getXCode();
                        String baiduLat = componentDetail.getYCode();
                        double[] doubles = CoordTransform.transformBD09ToWGS84(Double.valueOf(baiduLng), Double.valueOf(baiduLat));
                        for(int i = 0; i < doubles.length; i++) {
                            String WGS84Lng = String.valueOf(doubles[0]);
                            componentsSearchVo.setXCode(WGS84Lng);
                            String WGS84Lat = String.valueOf(doubles[1]);
                            componentsSearchVo.setYCode(WGS84Lat);
                        }
                        componentsSearchVos.add(componentsSearchVo);
                    });
                }
            break;
            case GRID:
                List<ComponentDetail> componentDetailListDyGrid = dyGridMapper.selectDetailComponents(code,componentCode,componentName);
                if(CollectionUtil.isNotEmpty(componentDetailListDyGrid)) {
                    componentDetailListDyGrid.stream().forEach(componentDetail -> {
                        ComponentsSearchVo componentsSearchVo = new ComponentsSearchVo();
                        componentsSearchVo.setComponentAddress(componentDetail.getComponentAddress());
                        componentsSearchVo.setComponentLogo(componentDetail.getComponentLogo());
                        componentsSearchVo.setComponentCode(componentDetail.getComponentCode());
                        componentsSearchVo.setComponentName(componentDetail.getComponentName());
                        componentsSearchVo.setComponentSuperCode(componentDetail.getComponentSuperCode());
                        componentsSearchVo.setComponentSuperName(componentDetail.getComponentSuperName());
                        try {
                            if(null != componentDetail.getPatrolInspectionTime() && "" != componentDetail.getPatrolInspectionTime().toString()) {
                                LocalDateTime patrolInspectionTime = componentDetail.getPatrolInspectionTime();
                                SimpleDateFormat format =  new SimpleDateFormat("yyyy-MM-dd");
                                String format1 = format.format(format.parse(patrolInspectionTime.toString()));
                                log.info("巡检时间      "+format1);
                                String format2 = format.format(format.parse(DateTime.now().toString()));
                                log.info("当前时间      "+format2);
                                if(format1.equalsIgnoreCase(format2)) {
                                    componentsSearchVo.setIsPatrolInspection(ONE);
                                }else {
                                    componentsSearchVo.setIsPatrolInspection(ZERO);
                                }
                            }else {
                                componentsSearchVo.setIsPatrolInspection(ZERO);
                            }
                        } catch (ParseException e) {
                            log.error("时间转换失败"+e.getMessage());
                        }
                        String baiduLng = componentDetail.getXCode();
                        String baiduLat = componentDetail.getYCode();
                        double[] doubles = CoordTransform.transformBD09ToWGS84(Double.valueOf(baiduLng), Double.valueOf(baiduLat));
                        for(int i = 0; i < doubles.length; i++) {
                            String WGS84Lng = String.valueOf(doubles[0]);
                            componentsSearchVo.setXCode(WGS84Lng);
                            String WGS84Lat = String.valueOf(doubles[1]);
                            componentsSearchVo.setYCode(WGS84Lat);
                        }
                        componentsSearchVos.add(componentsSearchVo);
                    });
                }
            break;
        }
        return ResultBean.success(componentsSearchVos);
    }

    @Override
    public ResultBean<PatrolInspectionSumVoInDirection> selectTodaySumInDirection(String code, String type) {
        PatrolInspectionSumVoInDirection patrolInspectionSumVoInDirection = new PatrolInspectionSumVoInDirection();
        switch (type) {
            case DISTRICT:
                List<ComponentDetail> componentDetailsDistrict = cityGridMapper.selectTodaySum(code);
                patrolInspectionSumVoInDirection.setPatrolInspectionSum(String.valueOf(componentDetailsDistrict.size()));
                break;
            case STREET:
                List<ComponentDetail> componentDetailsStreet = streetGridMapper.selectTodaySum(code);
                patrolInspectionSumVoInDirection.setPatrolInspectionSum(String.valueOf(componentDetailsStreet.size()));
                break;
            case COMMUNITY:
                List<ComponentDetail> componentDetailsCommunity = communityGridMapper.selectTodaySum(code);
                patrolInspectionSumVoInDirection.setPatrolInspectionSum(String.valueOf(componentDetailsCommunity.size()));
                break;
            case GRID:
                List<ComponentDetail> componentDetailsDygrid = dyGridMapper.selectTodaySum(code);
                patrolInspectionSumVoInDirection.setPatrolInspectionSum(String.valueOf(componentDetailsDygrid.size()));
                break;
        }
        return ResultBean.success(patrolInspectionSumVoInDirection);
    }
}
