package com.hncy.service.wechat.applet.biz.service.impl;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.date.DateTime;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.hncy.common.dto.ResultBean;
import com.hncy.common.exception.custom.BusinessException;
import com.hncy.common.exception.custom.LocalBusinessException;
import com.hncy.service.wechat.applet.biz.entity.*;
import com.hncy.service.wechat.applet.biz.mapper.*;
import com.hncy.service.wechat.applet.biz.service.ComponentIssuesReportService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.hncy.service.wechat.applet.biz.service.ComponentsRemoteService;
import com.hncy.service.wechat.applet.biz.utils.FastdfsClientUtil;
import com.hncy.service.wechat.applet.biz.vo.RegTypesVo;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDateTime;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.UUID;

/**
 * <p>
 * 部件问题上报 服务实现类
 * </p>
 *
 * @author cs
 * @since 2021-11-02
 */
@Service
@Slf4j
public class ComponentIssuesReportServiceImpl extends ServiceImpl<ComponentIssuesReportMapper, ComponentIssuesReport> implements ComponentIssuesReportService {

    private static final String IN_GOOD_CONDITION = "完好";

    @Autowired
    private ComponentsRemoteService componentsRemoteService;
    @Autowired
    private ComponentIssuesReportMapper componentIssuesReportMapper;
    @Autowired
    private ComponentPictureMapper componentPictureMapper;
    @Autowired
    private ComponentPictureRelationMapper componentPictureRelationMapper;
    @Autowired
    private PlatformAuditMapper platformAuditMapper;
    @Autowired
    private ComponentDetailMapper componentDetailMapper;
    @Autowired
    private ComponentIssueReportRelationMapper componentIssueReportRelationMapper;


    @Override
    public ResultBean<List<RegTypesVo>> selectAllRegTypes(String componentReportCode, String componentReportName) {
        if(StrUtil.isBlank(componentReportCode) || StrUtil.isBlank(componentReportName)) {
            throw new BusinessException("请选择部件类型");
        }
        List<RegTypesVo> regTypesVos  = componentIssuesReportMapper.selectAllRegTypes(componentReportCode,componentReportName);
        log.info(regTypesVos.toString());
        return ResultBean.success(regTypesVos);
    }

    @Override
    public ResultBean saveComponentIssues(String regCondCode, String regCondName, String issueDescription, String componentReportCode, String componentReportName) {
        ComponentIssuesReport componentIssuesReport = new ComponentIssuesReport();
        componentIssuesReport.setRegCondCode(regCondCode);
        componentIssuesReport.setRegCondName(regCondName);
        componentIssuesReport.setIssueDescription(issueDescription);
        componentIssuesReport.setComponentReportCode(componentReportCode);
        componentIssuesReport.setComponentReportName(componentReportName);
        componentIssuesReport.setGmtCreate(DateTime.now());
        componentIssuesReport.setDeleted(0);
        componentIssuesReportMapper.insert(componentIssuesReport);
        return ResultBean.success();
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ResultBean componentReport(String componentName,
                                      String componentCode,
                                      String componentSuperName,
                                      String componentSuperCode,
                                      String componentAddress,
                                      String xCode,
                                      String yCode,
                                      DateTime reportTime,
                                      String regCondCode,
                                      String regCondName,
                                      String issueDescription,
                                      List<String> pictureIds,
                                      String reportNickName,
                                      List<String> componentLogos,
                                      String reportOpenId,
                                      String issueNumber) {
        log.info("上报人员微信Id:   " +reportOpenId);

        componentLogos.stream().forEach(componentLogo ->{
            ComponentDetail componentDetail = componentDetailMapper.selectByComponentLogo(componentLogo);
            if(ObjectUtil.isNotEmpty(componentDetail)) {
                if(!componentName.equalsIgnoreCase(componentDetail.getComponentName()) && !componentCode.equalsIgnoreCase(componentDetail.getComponentCode())) {
                    //问题上报的时候修改了部件的基本信息
                    //修改部件的巡检时间
                    int i = componentDetailMapper.savepatrolInspectionTime(LocalDateTime.now(), componentLogo);
                    if (i == 0) {
                        throw new BusinessException("部件问题上报失败，请重新上报");
                    }

                    //部件问题上报
                    ComponentIssuesReport componentIssuesReport = new ComponentIssuesReport();
                    componentIssuesReport.setComponentReportName(componentName);
                    componentIssuesReport.setComponentReportCode(componentCode);
                    componentIssuesReport.setRegCondName(regCondName);
                    componentIssuesReport.setRegCondCode(regCondCode);
                    componentIssuesReport.setIssueDescription(issueDescription);
                    componentIssuesReport.setDeleted(0);
                    componentIssuesReport.setGmtCreate(reportTime);
                    componentIssuesReport.setCreateBy(reportOpenId);
                    int insert = componentIssuesReportMapper.insert(componentIssuesReport);
                    if (insert == 0) {
                        throw new BusinessException("部件问题上报失败，请重新上报");
                    }
                    String issueId = componentIssuesReport.getId();

                    //新增关联关系
                    ComponentIssueReportRelation componentIssueReportRelation = new ComponentIssueReportRelation();
                    componentIssueReportRelation.setComponentIssuesId(issueId);
                    componentIssueReportRelation.setComponentObjId(componentDetail.getId());
                    //问题上报的关联关系不需要显示
                    componentIssueReportRelation.setDeleted(1);
                    componentIssueReportRelation.setGmtCreate(reportTime);
                    componentIssueReportRelation.setCreateBy(reportOpenId);
                    int insert2 = componentIssueReportRelationMapper.insert(componentIssueReportRelation);
                    if (insert2 == 0) {
                        throw new BusinessException("部件问题上报失败，请重新上报");
                    }

                    //上报问题与图片关联
                    pictureIds.stream().forEach(pictureId -> {
                        ComponentPictureRelation componentPictureRelation = new ComponentPictureRelation();
                        componentPictureRelation.setComponentDetailId(null);
                        componentPictureRelation.setComponentPictureId(pictureId);
                        componentPictureRelation.setComponentIssuesReportId(issueId);
                        componentPictureRelation.setDeleted(0);
                        componentPictureRelation.setGmtCreate(reportTime);
                        componentPictureRelation.setCreateBy(reportOpenId);
                        int insert1 = componentPictureRelationMapper.insert(componentPictureRelation);
                        if (insert1 == 0) {
                            throw new BusinessException("部件问题上报失败，请重新上报");
                        }
                    });

                    //如果部件案件条件不是完好则上报给城市管理系统
                    if (!IN_GOOD_CONDITION.equalsIgnoreCase(regCondName) && CollectionUtil.isNotEmpty(pictureIds)) {
                        Map<String, Object> map = new HashMap<>();
                        //获取图片
                        Map<String, String> fileMap = new HashMap<>();
                        pictureIds.stream().forEach(pictureId -> {
                            ComponentPicture componentPicture = componentPictureMapper.selectById(pictureId);
                            String pictureUrl = componentPicture.getComponentPictureUrl();
                            if (StrUtil.isNotBlank(pictureUrl)) {
                                String imageToBase64 = FastdfsClientUtil.image2Base64(pictureUrl);
                                fileMap.put(componentPicture.getComponentPictureName(), imageToBase64);
                            }
                        });
                        //获取案件主键：32位UUID
                        String caseInfoId = UUID.randomUUID().toString().replaceAll("-", "");
                        map.put("fileMap", fileMap);
                        map.put("caseInfoId", caseInfoId);
                        map.put("addr", componentAddress);
                        map.put("problemDesc", issueDescription);
                        map.put("bigClassCode", componentSuperCode);
                        map.put("bigClassName", componentSuperName);
                        map.put("subClassCode", componentCode);
                        map.put("subClassName", componentName);
                        map.put("regCondCode", regCondCode);
                        map.put("regCondName", regCondName);
                        map.put("lon", xCode);
                        map.put("lat", yCode);
                        try {
                            componentsRemoteService.reportByAR(map);
                        } catch (Exception e) {
                            log.error(e.getMessage());
                            throw new LocalBusinessException(432, "城管系统异常，请稍后再试");
                        }
                    }

                }else {
                    //修改部件的巡检时间
                    int i = componentDetailMapper.savepatrolInspectionTime(LocalDateTime.now(), componentLogo);
                    if (i == 0) {
                        throw new BusinessException("部件问题上报失败，请重新上报");
                    }
                    //部件问题上报
                    ComponentIssuesReport componentIssuesReport = new ComponentIssuesReport();
                    componentIssuesReport.setComponentReportName(componentDetail.getComponentName());
                    componentIssuesReport.setComponentReportCode(componentDetail.getComponentCode());
                    componentIssuesReport.setRegCondName(regCondName);
                    componentIssuesReport.setRegCondCode(regCondCode);
                    componentIssuesReport.setIssueDescription(issueDescription);
                    componentIssuesReport.setDeleted(0);
                    componentIssuesReport.setGmtCreate(reportTime);
                    componentIssuesReport.setCreateBy(reportOpenId);
                    int insert = componentIssuesReportMapper.insert(componentIssuesReport);
                    if (insert == 0) {
                        throw new BusinessException("部件问题上报失败，请重新上报");
                    }
                    String issueId = componentIssuesReport.getId();

                    //新增关联关系
                    ComponentIssueReportRelation componentIssueReportRelation = new ComponentIssueReportRelation();
                    componentIssueReportRelation.setComponentIssuesId(issueId);
                    componentIssueReportRelation.setComponentObjId(componentDetail.getId());
                    //问题上报的关联关系不需要显示
                    componentIssueReportRelation.setDeleted(1);
                    componentIssueReportRelation.setGmtCreate(reportTime);
                    componentIssueReportRelation.setCreateBy(reportOpenId);
                    int insert2 = componentIssueReportRelationMapper.insert(componentIssueReportRelation);
                    if (insert2 == 0) {
                        throw new BusinessException("部件问题上报失败，请重新上报");
                    }

                    //上报问题与图片关联
                    pictureIds.stream().forEach(pictureId -> {
                        ComponentPictureRelation componentPictureRelation = new ComponentPictureRelation();
                        componentPictureRelation.setComponentDetailId(null);
                        componentPictureRelation.setComponentPictureId(pictureId);
                        componentPictureRelation.setComponentIssuesReportId(issueId);
                        componentPictureRelation.setDeleted(0);
                        componentPictureRelation.setGmtCreate(reportTime);
                        componentPictureRelation.setCreateBy(reportOpenId);
                        int insert1 = componentPictureRelationMapper.insert(componentPictureRelation);
                        if (insert1 == 0) {
                            throw new BusinessException("部件问题上报失败，请重新上报");
                        }
                    });

                    //如果部件案件条件不是完好则上报给城市管理系统
                    if (!IN_GOOD_CONDITION.equalsIgnoreCase(regCondName) && CollectionUtil.isNotEmpty(pictureIds)) {
                        Map<String, Object> map = new HashMap<>();
                        //获取图片
                        Map<String, String> fileMap = new HashMap<>();
                        pictureIds.stream().forEach(pictureId -> {
                            ComponentPicture componentPicture = componentPictureMapper.selectById(pictureId);
                            String pictureUrl = componentPicture.getComponentPictureUrl();
                            if (StrUtil.isNotBlank(pictureUrl)) {
                                String imageToBase64 = FastdfsClientUtil.image2Base64(pictureUrl);
                                fileMap.put(componentPicture.getComponentPictureName(), imageToBase64);
                            }
                        });
                        //获取案件主键：32位UUID
                        String caseInfoId = UUID.randomUUID().toString().replaceAll("-", "");
                        map.put("fileMap", fileMap);
                        map.put("caseInfoId", caseInfoId);
                        map.put("addr", componentAddress);
                        map.put("problemDesc", issueDescription);
                        map.put("bigClassCode", componentDetail.getComponentSuperCode());
                        map.put("bigClassName", componentDetail.getComponentSuperName());
                        map.put("subClassCode", componentDetail.getComponentCode());
                        map.put("subClassName", componentDetail.getComponentName());
                        map.put("regCondCode", regCondCode);
                        map.put("regCondName", regCondName);
                        map.put("lon", xCode);
                        map.put("lat", yCode);
                        try {
                            componentsRemoteService.reportByAR(map);
                        } catch (Exception e) {
                            log.error(e.getMessage());
                            throw new LocalBusinessException(432, "城管系统异常，请稍后再试");
                        }
                    }
                }
            }
        });
        return ResultBean.success("部件问题上报成功");
    }
}
