package com.hncy.service.wechat.applet.biz.service.impl;

import cn.hutool.core.date.DateTime;
import com.hncy.common.dto.ResultBean;
import com.hncy.common.exception.custom.BusinessException;
import com.hncy.common.exception.custom.LocalBusinessException;
import com.hncy.service.wechat.applet.biz.entity.ComponentPicture;
import com.hncy.service.wechat.applet.biz.mapper.ComponentPictureMapper;
import com.hncy.service.wechat.applet.biz.service.ComponentPictureService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.hncy.service.wechat.applet.biz.utils.FastdfsClientUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;

import java.util.ArrayList;
import java.util.List;

/**
 * <p>
 * 部件图片表 服务实现类
 * </p>
 *
 * @author cs
 * @since 2021-11-04
 */
@Service
@Slf4j
public class ComponentPictureServiceImpl extends ServiceImpl<ComponentPictureMapper, ComponentPicture> implements ComponentPictureService {

    //文件储存ip地址
    @Value("${file.upload}")
    private String basePath;

    @Autowired
    private ComponentPictureMapper componentPictureMapper;

    @Autowired
    private FastdfsClientUtil fastdfsClientUtil;



    @Override
    public ResultBean deletePictures(List<String> ids) {
        List<ComponentPicture> componentPictureList = componentPictureMapper.selectBatchIds(ids);
        componentPictureList
                .stream()
                .filter(componentPicture -> (componentPicture.getDeleted() == 0))
                .forEach(componentPicture -> {
                    int i = componentPictureMapper.deletePictures(componentPicture.getId());
                    if(i == 0) {
                        throw new BusinessException("文件删除失败");
                    }else {
                        fastdfsClientUtil.deleteFile(componentPicture.getComponentPictureUrl());
                    }
                });
        return ResultBean.success("文件删除成功");


    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ResultBean<ComponentPicture>  uploadComponentPicture(MultipartFile file, String storageForm, String wxUserOpenId) {
        //上传文件 返回文件地址
        String upload=null;
        //文件名
        String fileName = file.getOriginalFilename();
        //后缀类型并转为小写
        String suffixName = fileName.substring(fileName.lastIndexOf(".")).substring(1).toLowerCase();
        //图片上传
        try {
            upload = fastdfsClientUtil.upload(file);
        } catch (Exception e) {
            log.error("图片上传失败"+e.getMessage());
            throw new LocalBusinessException(435,"图片上传失败");
        }
        //文件大小
        long size = file.getSize();
        //文件全地址
        String allPath = basePath +upload;
        ComponentPicture componentPicture = new ComponentPicture();
        componentPicture.setComponentPictureSize(size+"");
        componentPicture.setComponentPictureUrl(allPath);
        componentPicture.setComponentPictureName(fileName);
        componentPicture.setComponentPictureType(suffixName);
        componentPicture.setCreateBy(wxUserOpenId);
        componentPicture.setGmtCreate(DateTime.now());
        componentPictureMapper.insert(componentPicture);
        log.info("当前的图片"+componentPicture.getId());
        return ResultBean.success(componentPicture);
    }
}
