package com.hncy.service.wechat.applet.biz.service.impl;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.hncy.common.dto.ResultBean;
import com.hncy.service.wechat.applet.biz.entity.*;
import com.hncy.service.wechat.applet.biz.mapper.*;
import com.hncy.service.wechat.applet.biz.service.ComponentTypeService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.hncy.service.wechat.applet.biz.service.ComponentsRemoteService;
import com.hncy.service.wechat.applet.biz.vo.*;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * <p>
 * 部件类型 服务实现类
 * </p>
 *
 * @author cs
 * @since 2021-11-02
 */
@Service
@Slf4j
public class ComponentTypeServiceImpl extends ServiceImpl<ComponentTypeMapper, ComponentType> implements ComponentTypeService {

    @Autowired
    private ComponentsRemoteService componentsRemoteService;
    @Autowired
    private ComponentTypeMapper componentTypeMapper;
    @Autowired
    private ComponentIssuesReportMapper componentIssuesReportMapper;
    @Autowired
    private ComponentDetailMapper componentDetailMapper;
    @Autowired
    private CityGridMapper cityGridMapper;
    @Autowired
    private CommunityGridMapper communityGridMapper;
    @Autowired
    private StreetGridMapper streetGridMapper;
    @Autowired
    private DyGridMapper dyGridMapper;

    private static final String GRID = "grid";
    private static final String COMMUNITY = "community";
    private static final String STREET = "street";
    private static final String DISTRICT = "district";

    @Override
    public ResultBean getComponentTypeAndRegCondByCtiySys() {
        Map<String, Object> stringObjectMap = componentsRemoteService.queryTypeAndRegCond();
        //部门大小类
        List<Map<String,String>> typeLists = (List<Map<String, String>>) stringObjectMap.get("typeList");
        for(Map<String,String> typeList : typeLists) {
            String subClassName = typeList.get("subClassName");
            String subClassCode = typeList.get("subClassCode");
            String bigClassName = typeList.get("bigClassName");
            String bigClassCode = typeList.get("bigClassCode");

            ComponentType componentType = new ComponentType();
            componentType.setComponentCode(subClassCode);
            componentType.setComponentName(subClassName);
            componentType.setComponentSuperCode(bigClassCode);
            componentType.setComponentSuperCode(bigClassName);
            componentTypeMapper.insert(componentType);
        }
        //上报问题案件类型
        List<Map<String,String>> regCondLists = (List<Map<String, String>>) stringObjectMap.get("regCondList");
        for (Map<String,String> regCondList : regCondLists) {
            String subClassCode = regCondList.get("subClassCode");
            String subClassName = regCondList.get("subClassName");
            String regCondCode = regCondList.get("regCondCode");
            String regCondName = regCondList.get("regCondName");
            ComponentIssuesReport componentIssuesReport = new ComponentIssuesReport();
            componentIssuesReport.setRegCondCode(regCondCode);
            componentIssuesReport.setRegCondName(regCondName);
            componentIssuesReport.setComponentReportCode(subClassCode);
            componentIssuesReport.setComponentReportName(subClassName);
            componentIssuesReportMapper.insert(componentIssuesReport);
        }
        return ResultBean.success();
    }

    @Override
    public ResultBean<List<ComponentTypesVo>> selectAllTypes() {
        List<ComponentTypesVo> componentTypesVos  = componentDetailMapper.selectAllTypes();
        log.info(componentTypesVos.toString());
        return ResultBean.success(componentTypesVos);
    }

    @Override
    public ResultBean<List<ComponentSubTypesVo>> selectAllTypesBySub(String componentSuperName, String componentSuperCode, String componentTypeCode, String componentTypeName) {
        log.info("componentSuperName"+componentSuperName);
        log.info("componentSuperCode"+componentSuperCode);
        List<ComponentSubTypesVo> componentSubTypesVos = componentDetailMapper.selectAllTypesBySub(componentSuperName,componentSuperCode,componentTypeCode,componentTypeName);
        log.info(componentSubTypesVos.toString());
        return ResultBean.success(componentSubTypesVos);
    }

    @Override
    public ResultBean<List<ComponentSupperVo>> selectAllTypesBySupperComponents(String code, String type) {
        List<ComponentSupperVo> componentSupperVos = new ArrayList<>();
        switch (type){
            case DISTRICT:
                List<ComponentDetail> componentDetails = cityGridMapper.selectAllTypesBySupperComponents(code);
                if(CollectionUtil.isNotEmpty(componentDetails)) {
                    Map<String,List<ComponentDetail>> map = componentDetails.stream().collect(Collectors.groupingBy(ComponentDetail::getComponentSuperName));
                    for(String componentSuperName : map.keySet()) {
                        ComponentSupperVo componentSupperVo = new ComponentSupperVo();
                        List<ComponentSubNameVo> componentSubNameVos = new ArrayList<>();
                        List<ComponentDetail> componentDetails1 = map.get(componentSuperName);
                        Map<String,List<ComponentDetail>> map1 = componentDetails1.stream().collect(Collectors.groupingBy(ComponentDetail::getComponentName));
                        for(String componentName : map1.keySet()) {
                            ComponentSubNameVo componentSubNameVo = new ComponentSubNameVo();
                            componentSubNameVo.setComponentName(componentName);
                            ComponentType componentType = componentTypeMapper.selectBySuperNameAndName(componentSuperName,componentName);
                            componentSubNameVo.setComponentCode(componentType.getComponentCode());
                            componentSupperVo.setComponentSuperName(componentSuperName);
                            componentSupperVo.setComponentSuperCode(componentType.getComponentSuperCode());
                            componentSubNameVo.setComponentTypeSum(String.valueOf(map1.get(componentName).stream().count()));
                            //查询该类部件今日巡检数
                            String todayPatrolInspectionSumDistrict = cityGridMapper.selectTodayPatrolInspectionSum(code, componentName, componentType.getComponentCode());
                            componentSubNameVo.setComponentInspectionSum(todayPatrolInspectionSumDistrict);
                            componentSubNameVos.add(componentSubNameVo);
                            componentSupperVo.setChildren(componentSubNameVos);
                        }
                        componentSupperVos.add(componentSupperVo);
                    }
                }
                break;
            case STREET:
                List<ComponentDetail> componentDetails2 = streetGridMapper.selectAllTypesBySupperComponents(code);
                if(CollectionUtil.isNotEmpty(componentDetails2)) {
                    Map<String,List<ComponentDetail>> map = componentDetails2.stream().collect(Collectors.groupingBy(ComponentDetail::getComponentSuperName));
                    for(String componentSuperName : map.keySet()) {
                        ComponentSupperVo componentSupperVo = new ComponentSupperVo();
                        List<ComponentSubNameVo> componentSubNameVos = new ArrayList<>();
                        List<ComponentDetail> componentDetailSupers1 = map.get(componentSuperName);
                        Map<String,List<ComponentDetail>> map1 = componentDetailSupers1.stream().collect(Collectors.groupingBy(ComponentDetail::getComponentName));
                        for(String componentName : map1.keySet()) {
                            ComponentSubNameVo componentSubNameVo = new ComponentSubNameVo();
                            componentSubNameVo.setComponentName(componentName);
                            ComponentType componentType = componentTypeMapper.selectBySuperNameAndName(componentSuperName,componentName);
                            componentSubNameVo.setComponentCode(componentType.getComponentCode());
                            componentSupperVo.setComponentSuperName(componentSuperName);
                            componentSupperVo.setComponentSuperCode(componentType.getComponentSuperCode());
                            componentSubNameVo.setComponentTypeSum(String.valueOf(map1.get(componentName).size()));
                            //查询该类部件今日巡检数
                            String todayPatrolInspectionSumStreet = streetGridMapper.selectTodayPatrolInspectionSum(code, componentName, componentType.getComponentCode());
                            componentSubNameVo.setComponentInspectionSum(todayPatrolInspectionSumStreet);
                            componentSubNameVos.add(componentSubNameVo);
                            componentSupperVo.setChildren(componentSubNameVos);
                        }
                        componentSupperVos.add(componentSupperVo);
                    }
                }
                break;
            case COMMUNITY:
                List<ComponentDetail> componentDetails3 = communityGridMapper.selectAllTypesBySupperComponents(code);
                if(CollectionUtil.isNotEmpty(componentDetails3)) {
                    Map<String,List<ComponentDetail>> map = componentDetails3.stream().collect(Collectors.groupingBy(ComponentDetail::getComponentSuperName));
                    for(String componentSuperName : map.keySet()) {
                        ComponentSupperVo componentSupperVo = new ComponentSupperVo();
                        List<ComponentSubNameVo> componentSubNameVos = new ArrayList<>();
                        List<ComponentDetail> componentDetailSupers2 = map.get(componentSuperName);
                        Map<String,List<ComponentDetail>> map1 = componentDetailSupers2.stream().collect(Collectors.groupingBy(ComponentDetail::getComponentName));
                        for(String componentName : map1.keySet()) {
                            ComponentSubNameVo componentSubNameVo = new ComponentSubNameVo();
                            componentSubNameVo.setComponentName(componentName);
                            ComponentType componentType = componentTypeMapper.selectBySuperNameAndName(componentSuperName,componentName);
                            componentSubNameVo.setComponentCode(componentType.getComponentCode());
                            componentSupperVo.setComponentSuperName(componentSuperName);
                            componentSupperVo.setComponentSuperCode(componentType.getComponentSuperCode());
                            componentSubNameVo.setComponentTypeSum(String.valueOf(map1.get(componentName).size()));
                            //查询该类部件今日巡检数
                            String todayPatrolInspectionSumCommunity = communityGridMapper.selectTodayPatrolInspectionSum(code, componentName, componentType.getComponentCode());
                            componentSubNameVo.setComponentInspectionSum(todayPatrolInspectionSumCommunity);
                            componentSubNameVos.add(componentSubNameVo);
                            componentSupperVo.setChildren(componentSubNameVos);
                        }
                        componentSupperVos.add(componentSupperVo);
                    }
                }
                break;
            case GRID:
                List<ComponentDetail> componentDetails4 = dyGridMapper.selectAllTypesBySupperComponents(code);
                if(CollectionUtil.isNotEmpty(componentDetails4)) {
                    Map<String,List<ComponentDetail>> map = componentDetails4.stream().collect(Collectors.groupingBy(ComponentDetail::getComponentSuperName));
                    for(String componentSuperName : map.keySet()) {
                        ComponentSupperVo componentSupperVo = new ComponentSupperVo();
                        List<ComponentSubNameVo> componentSubNameVos = new ArrayList<>();
                        List<ComponentDetail> componentDetailSupers3 = map.get(componentSuperName);
                        Map<String,List<ComponentDetail>> map1 = componentDetailSupers3.stream().collect(Collectors.groupingBy(ComponentDetail::getComponentName));
                        for(String componentName : map1.keySet()) {
                            ComponentSubNameVo componentSubNameVo = new ComponentSubNameVo();
                            componentSubNameVo.setComponentName(componentName);
                            ComponentType componentType = componentTypeMapper.selectBySuperNameAndName(componentSuperName,componentName);
                            componentSubNameVo.setComponentCode(componentType.getComponentCode());
                            componentSupperVo.setComponentSuperName(componentSuperName);
                            componentSupperVo.setComponentSuperCode(componentType.getComponentSuperCode());
                            componentSubNameVo.setComponentTypeSum(String.valueOf(map1.get(componentName).size()));
                            //查询该类部件今日巡检数
                            String todayPatrolInspectionSumDyGrid = dyGridMapper.selectTodayPatrolInspectionSum(code, componentName, componentType.getComponentCode());
                            componentSubNameVo.setComponentInspectionSum(todayPatrolInspectionSumDyGrid);
                            componentSubNameVos.add(componentSubNameVo);
                            componentSupperVo.setChildren(componentSubNameVos);
                        }
                        componentSupperVos.add(componentSupperVo);
                    }
                }
                break;
        }
        return ResultBean.success(componentSupperVos);
    }
}
