package com.hncy.service.wechat.applet.biz.service.impl;

import cn.hutool.core.date.DateTime;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.hncy.common.dto.ResultBean;
import com.hncy.common.exception.custom.BusinessException;
import com.hncy.common.exception.custom.LocalBusinessException;
import com.hncy.pageable.spring.boot.starter.core.Page;
import com.hncy.service.wechat.applet.biz.entity.*;
import com.hncy.service.wechat.applet.biz.mapper.*;
import com.hncy.service.wechat.applet.biz.service.ComponentsRemoteService;
import com.hncy.service.wechat.applet.biz.service.PlatformAuditService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.hncy.service.wechat.applet.biz.vo.AuditComponentVo;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;

/**
 * <p>
 * 平台端审核表 服务实现类
 * </p>
 *
 * @author cs
 * @since 2021-11-04
 */
@Service
public class PlatformAuditServiceImpl extends ServiceImpl<PlatformAuditMapper, PlatformAudit> implements PlatformAuditService {

    private static final String THREE = "3";

    @Autowired
    private PlatformAuditMapper platformAuditMapper;
    @Autowired
    private ComponentDetailMapper componentDetailMapper;
    @Autowired
    private ComponentIssuesReportMapper componentIssuesReportMapper;
    @Autowired
    private ComponentIssueReportRelationMapper componentIssueReportRelationMapper;
    @Autowired
    private ComponentPictureMapper componentPictureMapper;
    @Autowired
    private ComponentPictureRelationMapper componentPictureRelationMapper;
    @Autowired
    private ComponentsRemoteService componentsRemoteService;
    @Autowired
    private CommunityGridMapper communityGridMapper;
    @Autowired
    private StreetGridMapper streetGridMapper;


    @Override
    public ResultBean<Page<PlatformAudit>> searchPlatformAuditlist(int pageNum, int pageSize, String auditStatus) {
        Page<PlatformAudit> platformAuditPage =Page.doSelectPage(() ->platformAuditMapper.searchPlatformAuditlist(auditStatus));
        return ResultBean.success(platformAuditPage);

    }

    @Override
    public ResultBean<AuditComponentVo> selectDetailAudit(String id, String componentDetailId, String componentIssuesReportId) {
        List<String> pictureUrls = new ArrayList<>();
        PlatformAudit platformAudit = platformAuditMapper.selectById(id);
        ComponentDetail componentDetail = componentDetailMapper.selectById(componentDetailId);
        ComponentIssuesReport componentIssuesReport = componentIssuesReportMapper.selectById(componentIssuesReportId);
        AuditComponentVo auditComponentVo = new AuditComponentVo();

        auditComponentVo.setRegCondCode(componentIssuesReport.getRegCondCode());
        auditComponentVo.setRegCondName(componentIssuesReport.getRegCondName());
        auditComponentVo.setIssueDescription(componentIssuesReport.getIssueDescription());
        auditComponentVo.setComponentSuperName(componentDetail.getComponentSuperName());
        auditComponentVo.setComponentSuperCode(componentDetail.getComponentSuperCode());
        auditComponentVo.setComponentTypeName(componentDetail.getComponentTypeName());
        auditComponentVo.setComponentTypeCode(componentDetail.getComponentCode());
        auditComponentVo.setComponentName(componentDetail.getComponentName());
        auditComponentVo.setComponentCode(componentDetail.getComponentCode());
        auditComponentVo.setComponentLogo(componentDetail.getComponentLogo());
        auditComponentVo.setComponentAddress(componentDetail.getComponentAddress());
        auditComponentVo.setReporter(platformAudit.getComponentCollector());
        auditComponentVo.setReportTime(componentDetail.getGmtCreate());
        auditComponentVo.setAuditTime(platformAudit.getAuditTime());
        auditComponentVo.setAuditStatus(platformAudit.getAuditStatus());
        List<ComponentPictureRelation> componentPictureRelationList = componentPictureRelationMapper.selectDetailAudit(componentDetailId);
        componentPictureRelationList.stream().forEach(componentPictureRelation -> {
            if(StrUtil.isNotBlank(componentPictureRelation.getComponentPictureId())) {
                ComponentPicture componentPicture = componentPictureMapper.selectById(componentPictureRelation.getComponentPictureId());
                String url = componentPicture.getComponentPictureUrl();
                pictureUrls.add(url);
            }
        });
        auditComponentVo.setPictureUrls(pictureUrls);
        return ResultBean.success(auditComponentVo);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ResultBean updateAuditStatus(String id, String componentId, String auditStatus, String componentLogo) {
        //不能传入重复的componentLogo
        if(!"".equalsIgnoreCase(componentLogo)) {
            ComponentDetail c = componentDetailMapper.selectByComponentLogo(componentLogo);
            if(ObjectUtil.isNotEmpty(c)) {
                throw new LocalBusinessException(431,"该部件标识号已存在于城市管理系统部件库，请重新输入");
            }
        }
        //修改部件logo
        ComponentDetail componentDetail = new ComponentDetail();
        componentDetail.setComponentLogo(componentLogo);
        componentDetail.setId(componentId);
        componentDetail.setGmtModified(DateTime.now());
        int i = componentDetailMapper.updateById(componentDetail);
        if(i == 0) {
            throw new BusinessException("修改审核状态失败");
        }
        //修改部件审核状态
        PlatformAudit platformAudit = new PlatformAudit();
        platformAudit.setAuditTime(DateTime.now());
        platformAudit.setAuditStatus(auditStatus);
        platformAudit.setId(id);
        int i1 = platformAuditMapper.updateById(platformAudit);
        if(i1 == 0) {
            throw new BusinessException("修改审核状态失败");
        }
        //如果是审核成功的部件则上报给城管系统
        if(THREE.equalsIgnoreCase(auditStatus)) {
            ComponentDetail componentDetail1 = componentDetailMapper.selectById(componentId);
            Map<String, Object> map = new HashMap<>();
            String reportId = UUID.randomUUID().toString().replaceAll("-", "");
            map.put("id",reportId);
            map.put("objCode",componentDetail1.getComponentCode());
            map.put("objName",componentDetail1.getComponentLogo());
            map.put("superviseDeptId",null);
            map.put("superviseDeptName",null);
            map.put("belongDeptId",null);
            map.put("belongDeptName",null);
            map.put("maintainDeptId",null);
            map.put("maintainDeptName",null);
            map.put("material",null);
            map.put("objAddr",componentDetail1.getComponentAddress());

            CommunityGrid communityGrid = communityGridMapper.selectCommunityByComponent(componentId);
            if(ObjectUtil.isNotEmpty(communityGrid)) {
                map.put("community",communityGrid.getComid());
                map.put("communityName",communityGrid.getComname());
            }else {
                map.put("community",null);
                map.put("communityName",null);
            }
            StreetGrid streetGrid = streetGridMapper.selectCommunityByComponent(componentId);
            if(ObjectUtil.isNotEmpty(streetGrid)) {
                map.put("committee",streetGrid.getStreetid());
                map.put("committeeName",streetGrid.getStreetname());
            }else {
                map.put("committee",null);
                map.put("committeeName",null);
            }
            map.put("unitCode",null);
            map.put("xpoint",componentDetail1.getXCode());
            map.put("ypoint",componentDetail1.getYCode());
            map.put("objCreateDate",componentDetail1.getGmtCreate().toString());
            map.put("objChangeDate",componentDetail1.getGmtModified().toString());
            map.put("dictionaryId",componentDetail1.getComponentCode());
            try {
                componentsRemoteService.syncComponentByAR(map);
            }catch (Exception e) {
                log.error(e.getMessage());
                throw new LocalBusinessException(432,"城管系统异常，请稍后再试");
            }
        }
        return ResultBean.success("修改审核状态成功");
    }


}
