package com.hncy.service.wechat.applet.biz.utils;

import org.apache.commons.codec.binary.Base64;
import org.bouncycastle.jce.provider.BouncyCastleProvider;

import javax.crypto.Cipher;
import javax.crypto.KeyGenerator;
import javax.crypto.spec.IvParameterSpec;
import javax.crypto.spec.SecretKeySpec;
import java.security.AlgorithmParameters;
import java.security.Key;
import java.security.Security;


/**
 * 微信小程序 --- 获取用户信息解密
 * @author caosu
 * @date 2021/5/18
 **/
 
public class WechatUtils {
	
	public static final String AES = "AES";
	public static final String AES_CBC_PADDING = "AES/CBC/PKCS7Padding";
 
	/**
     *开放数据校验与解密 <br/>
     *对称解密使用的算法为 AES-128-CBC，数据采用PKCS#7填充<br/>
     *对称解密的目标密文:encrypted=Base64_Decode(encryptData)<br/>
     *对称解密秘钥:key = Base64_Decode(session_key),aeskey是16字节<br/>
     *对称解密算法初始向量:iv = Base64_Decode(iv),同样是16字节<br/>
     *@param encrypted 目标密文
     *@param session_key 会话ID
     *@param iv 加密算法的初始向量
     *@see https://developers.weixin.qq.com/miniprogram/dev/framework/open-ability/signature.html
     */
    public static String wxDecrypt(String encrypted, String session_key, String iv) {
        String result = null;
        byte[] encrypted64 = Base64.decodeBase64(encrypted);
        byte[] key64 = Base64.decodeBase64(session_key);
        byte[] iv64 = Base64.decodeBase64(iv);
        try {
            init();
            result = new String(decrypt(encrypted64, key64, generateIV(iv64)));
        } catch (Exception e) {
            e.printStackTrace();
        }
        return result;
    }
	    
   
	    
    /**
     * description: 初始化密钥
     * @throws Exception
     * @return void
     * @author caosu
     * @date 2021/5/18
     */
    public static void init() throws Exception {
        Security.addProvider(new BouncyCastleProvider());
        KeyGenerator.getInstance(AES).init(128);
    }
 
    /**
     * description: 生成iv
     * @param iv
     * @throws Exception
     * @return AlgorithmParameters
     * @author caosu
     * @date 2021/5/18
     */
    public static AlgorithmParameters generateIV(byte[] iv) throws Exception {
        // iv 为一个 16 字节的数组
        AlgorithmParameters params = AlgorithmParameters.getInstance(AES);
        params.init(new IvParameterSpec(iv));
        return params;
    }
 
    /**
     * description: 执行解密操作
     * @param encryptedData  加密后的字符串
     * @param keyBytes  密钥key
     * @param iv  便宜向量iv
     * @throws Exception
     * @return byte[]
     * @author caosu
     * @date 2021/5/18
     */
    public static byte[] decrypt(byte[] encryptedData, byte[] keyBytes, AlgorithmParameters iv)throws Exception {
        Key key = new SecretKeySpec(keyBytes, AES);
        Cipher cipher = Cipher.getInstance(AES_CBC_PADDING);
        // 设置为解密模式
        cipher.init(Cipher.DECRYPT_MODE, key, iv);
        return cipher.doFinal(encryptedData);
    }
    	  
}